### Script to create figures from Simulations_Final/Simulation_from0hAPF.
### Run multiple times with different suffixes such as results_shorter_pause etc.


N_RUNS = 10

#useful function
every_nth <- function(x, nth, empty = TRUE, inverse = FALSE) 
{
  if (!inverse) {
    if(empty) {
      x[1:nth == 1] <- ""
      x
    } else {
      x[1:nth != 1]
    }
  } else {
    if(empty) {
      x[1:nth != 1] <- ""
      x
    } else {
      x[1:nth == 1]
    }
  }
}
# egg to allow absolute panel size setting in ggplot2?
#install.packages("egg")
library("egg")

## script to do various things for figure 3, the bit where we compare the simulation for cell number etc. 
## first want to get the quantities of interest for all the WTs, probably TIME ALIGN THEM to WT2 by SOPs as normal
## and then make ribbon/error bar data series for them.
## then load in data for a sort of 'example'

## make panels like separately. 

offset_WT1 <- 0
offset_WT2 <- -62
offset_WT3 <- 5
offset_WT4 <- 7

## PANEL 1. Cell Number prior to 16h. We already have an R script that reads in Ana F's CSV and makes a consistent looking plot of it.
## so put that in. Then append with code to read in CSV simulation data for simulated cell number. 

# R Studio doesn't seem to be grabbing this env variable.
Sys.setenv(TM_HOME = "~/tissue_miner")
scriptsDir=Sys.getenv("TM_HOME")
outDataBaseDir="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/PAPER/FIG3/Fig3_results_shorter_pause/"
mcdir(outDataBaseDir)
# Load TissueMiner libraries
source(file.path(scriptsDir, "commons/TMCommons.R"))
source(file.path(scriptsDir, "db/movie_rotation/RotationFunctions.R"))
source(file.path(scriptsDir, "commons/BaseQueryFunctions.R"))
source(file.path(scriptsDir, "commons/TimeFunctions.R"))
source(file.path(scriptsDir, "config/default_config.R"))
source(file.path(scriptsDir, "iwanthue.R"))
source(file.path(scriptsDir, "commons/MovieFunctions.R"))

# Load a R library
## library("zoo")

# Set up working directory
mcdir(outDataBaseDir)

# Set general theme for graphs: more specific tuning must be done for each graph
theme_set(theme_bw())
theme_update(panel.grid.major=element_line(linetype= "dotted", color="black", size=0.2),
             panel.grid.minor = element_blank(),
             panel.border = element_rect(size=0.3,color="black",fill=NA),
             axis.ticks=element_line(size=0.2),
             axis.ticks.length=unit(0.1,"cm"),
             legend.key = element_blank()
)

## a colourblind palette? -- use first four for movieColors and last FIVE (backward) for isotropColors?
# no try colour brewer instead
# The palette with black:
#cbbPalette <- c("#000000", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")

# Hardwire isotropic deformation color scheme
isotropColors <- c("division"="#E41A1C",
                   "extrusion"="#377EB8",
                   "cell_area"="#4DAF4A",
                   "sumContrib"="#984EA3",
                   "tissue_area"="#FF7F00")

library(RColorBrewer)
display.brewer.all()
display.brewer.pal(n = 9, name = 'Set1')
brewer.pal(n = 9, name = "Set1")
# "#E41A1C" "#377EB8" "#4DAF4A" "#984EA3" "#FF7F00" "#FFFF33" "#A65628" "#F781BF" "#999999"
brewer.pal(n = 8, name = "Dark2")
# "#1B9E77" "#D95F02" "#7570B3" "#E7298A" "#66A61E" "#E6AB02" "#A6761D" "#666666"


# hardwire the movie color scheme
movieColors <- c("WT1"="#1B9E77",
                 "WT2"="#D95F02",
                 "WT3"="#7570B3",
                 "WT4"="#E7298A"
)

## Shear
shearColors <- c(
  "total_shear"="blue",
  "cell_elongation_change"="darkgreen",
  "T1"="red",
  "T2"="turquoise",
  "cell_division"="orange",
  "correlation_effects"="magenta",
  "sum_contrib"="salmon",
  "sumContrib"="salmon",
  "check"="yellow",
  "crc"="pink", "cagc"="lightgreen",
  "ct"="grey",
  "J"="grey",
  "CEwithCT"="darkgreen",
  "av_total_shear"="blue",
  "nu"="blue",
  "ShearT1"="red",
  "ShearT2"="turquoise",
  "ShearCD"="orange",
  "correlationEffects"="magenta",
  "sumContrib"="salmon")

#Extras commonly needed:
#Jet Colors
jet.colors <- colorRampPalette(c("#00007F", "blue", "#007FFF", "cyan", "#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"))

# Save plot function
savePlot <- function(myPlot) {
  pdf("myPlot.pdf")
  print(myPlot)
  dev.off()
}

### LOADING IN DATA AND MAKING GRAPH SECTION


graphdata <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Other/JJW_Simulations_previously_Fig3/cell_number_earlystages/cell_number_anterior_earlystages_points.csv",header=FALSE)
graphdata <- graphdata %>% rename(dev_time = V1, y = V2) 

graphdata2 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Other/JJW_Simulations_previously_Fig3/cell_number_earlystages/cell_number_anterior_earlystages_avgs.csv",header=FALSE)
graphdata2 <- graphdata2 %>% rename(dev_time = V1, y = V2, err_y = V3)
graphdata2 <- graphdata2 %>% na.omit()

### read in the simulated pre-16h cell number.
graphdata3 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/copy_18Nov_jjw_GS_Sim_Population_Growth_Python/results/nb_cells_all_typesWT1.csv",header=FALSE,sep=" ")
graphdata3 <- graphdata3 %>% rename(dev_time = V1, y = V2)

## make graph by looking at the original pdf and replicating it
myplot <- ggplot(graphdata, aes(dev_time, y)) +
  geom_point(size=0.8, color="aquamarine3", position = position_jitter(w = 0, h = 0)) + 
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_errorbar(data=graphdata2,aes(dev_time,ymin=(y-err_y), ymax=(y+err_y)),size=0.8, width=20/40,color="black") +
  geom_point(data=graphdata2,aes(dev_time,y),size=0.8,color="black") +
  geom_line(data=graphdata3, aes(dev_time,y), size=0.6, color="grey35") + 
  xlab("Time (hAPF)")+
  ylab(expression(paste("Cell number"))) +
  scale_y_continuous(limits=c(0,405),expand = c(0,0), breaks=c(0,100,200,300,400)) +
  scale_x_continuous(limits=c(0,18), breaks=c(0,2,4,6,8,10,12,14,16), expand = c(0,0), labels = every_nth(c(0,2,4,6,8,10,12,14,16), 2, inverse = TRUE))  
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("cell_number_earlystages_R_plus_simulation.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## STATISTICAL VERSION 19 APRIL 2020: do as above but with a modified simulation read in that takes the multiple runs in
## borrow code from starat16h_statistical.R. 
for (i in seq(0,N_RUNS-1)) {
  # noborder number
  filename = gsub(" \\d ", paste(i), paste("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/nb_cells_first_phase_all_types_run_",i,".csv",sep=""))
  temp <- read.csv(filename,header=FALSE, sep= " ") %>% na.omit() 
  colnames(temp) <- c("dev_time", "n")
  temp$series <- "pre16h"
  temp$run <- i
  
  filename = gsub(" \\d ", paste(i), paste("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/nb_cells_second_phase_total_all_types_run_",i,".csv",sep=""))
  temp1 <- read.csv(filename,header=FALSE, sep= " ") %>% na.omit() 
  colnames(temp1) <- c("dev_time", "n")
  temp1$series <- "pre16h"
  temp1$run <- i
  
  temp <- rbind(temp,temp1)
  
  if (i == 0)  {
    sim_pre16h_statistical <- temp
  } else {
    sim_pre16h_statistical <- rbind(sim_pre16h_statistical,temp)  
  }
}
sim_pre16h_statistical <- sim_pre16h_statistical %>% group_by(dev_time) %>% summarise(mean = mean(n),sd = sd(n), series="pre16h")

myplot <- ggplot() +
  geom_point(data=graphdata, aes(dev_time, y),size=0.8, color="aquamarine3", position = position_jitter(w = 0, h = 0)) + 
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_errorbar(data=graphdata2,aes(dev_time,ymin=(y-err_y), ymax=(y+err_y)),size=0.8, width=20/40,color="black") +
  geom_point(data=graphdata2,aes(dev_time,y),size=0.8,color="black") +
  geom_ribbon(data=sim_pre16h_statistical,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd)),fill= "grey35",color="grey35",size=0.25, alpha=0.5) + 
  geom_line(data=sim_pre16h_statistical,aes(dev_time,y=mean),fill= "grey35",color="grey35",size=0.8, alpha=0.9) + 
  #geom_line(data=graphdata3, aes(dev_time,y), size=0.6, color="grey35") + 
  xlab("Time (hAPF)")+
  ylab(expression(paste("Cell number"))) +
  scale_y_continuous(limits=c(0,425),expand = c(0,0), breaks=c(0,100,200,300,400)) +
  scale_x_continuous(limits=c(0,18), breaks=c(0,2,4,6,8,10,12,14,16), expand = c(0,0), labels = every_nth(c(0,2,4,6,8,10,12,14,16), 2, inverse = TRUE))  
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("STATISTICAL_cell_number_earlystages_R_plus_simulation.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## END STATISTICAL VERSION





### 17 FEB 2020 18 FEB 2020 GS REQUEST.  as fig 3d but 
# Could you generate a new plot like Fig. 3D, but with log_2(N/N0) on the y axis (to evaluate the number of divisions), and add it to Fig S3?
# do this only for the MEANS and SIMULATION data, i.e. not the raw points since it's not clear what N0 to normalise by
N0_graphdata2 <- min(graphdata2$y)
log2_graphdata2 <- graphdata2 %>% mutate(y = log2(y/N0_graphdata2))
# need to handle the log2 thing when plotting error bar 
N0_sim_pre16h_statistical <- min(sim_pre16h_statistical$mean)
log2_sim_pre16h_statistical <- sim_pre16h_statistical %>% mutate(y = log2(mean/N0_sim_pre16h_statistical))

myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_errorbar(data=log2_graphdata2,aes(dev_time,ymin=log2(((2^y)*N0_graphdata2-err_y)/N0_graphdata2), ymax=log2(((2^y)*N0_graphdata2+err_y)/N0_graphdata2)),size=0.8,width=20/40,color="black") +
  geom_point(data=log2_graphdata2,aes(dev_time,y),size=0.8,color="black") +
  geom_line(data=log2_sim_pre16h_statistical, aes(dev_time,y), size=0.6, color="grey35") + 
  xlab("Time (hAPF)")+
  ylab(expression(paste("log2(N/N0)"))) +
  scale_y_continuous(limits=c(-0.2,4.5),expand = c(0,0), breaks=c(0,1,2,3,4,5)) +
  scale_x_continuous(limits=c(0,18), breaks=c(0,2,4,6,8,10,12,14,16), expand = c(0,0), labels = every_nth(c(0,2,4,6,8,10,12,14,16), 2, inverse = TRUE)) 
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("STATISTICAL_cell_number_earlystages_R_plus_simulation_log2version.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## DON'T NEED STATISTICAL VERSION FOR THIS
## DON'T NEED STATISTICAL VERSION FOR THIS


## PANEL 2) Cell cycle time used as input. But must also include the experiment cell lifetime data combined 
# load in WT1. 
WT1_lifetime <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/lifetimes_trend_noborder_25.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT1_lifetime <- WT1_lifetime %>% select(dev_time,mean_life,sd_life) %>% mutate(dev_time = dev_time + (offset_WT1*2.5/60)) %>% mutate(movie = "WT1")
# load in WT2. 
WT2_lifetime <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/lifetimes_trend_noborder_25.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT2_lifetime <- WT2_lifetime %>% select(dev_time,mean_life,sd_life) %>% mutate(dev_time = dev_time + (offset_WT2*2.5/60)) %>% mutate(movie = "WT2")
# load in WT3. 
WT3_lifetime <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/lifetimes_trend_noborder_25.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT3_lifetime <- WT3_lifetime %>% select(dev_time,mean_life,sd_life) %>% mutate(dev_time = dev_time + (offset_WT3*2.5/60)) %>% mutate(movie = "WT3")
# load in WT4. 
WT4_lifetime <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/lifetimes_trend_noborder_25.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT4_lifetime <- WT4_lifetime %>% select(dev_time,mean_life,sd_life) %>% mutate(dev_time = dev_time + (offset_WT4*2.5/60)) %>% mutate(movie = "WT4")
WTs_lifetime <- rbind(WT1_lifetime,WT2_lifetime,WT3_lifetime,WT4_lifetime)

## load in lifetime series used for simulation
graphdata4 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/cell_cycles_mean_std_first_phase_run_0.csv",header=FALSE,sep=" ")
graphdata4 <- graphdata4 %>% rename(dev_time = V1, y = V2, y_sd = V3)
graphdata5 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/cell_cycles_mean_std_second_phase_run_0.csv",header=FALSE,sep=" ")
graphdata4 <- graphdata5 %>% rename(dev_time = V1, y = V2, y_sd = V3) %>% rbind(graphdata4) %>% arrange(dev_time)

## plot all together somehow.
## THIS HAS AUTHORITATIVE PLOT STYLE.

## try to exclude lifetime where the pause is. 
## try to add in ana-F experimental lifetime measurements. 
graphdata6 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Other/JJW_Simulations_previously_Fig3/list_early_birthtime_lifetime_minutes.csv",header=FALSE,sep="\t")
graphdata6 <- graphdata6 %>% rename(dev_time=V1,y=V2) %>% mutate(dev_time = dev_time/60, y = y/60)

scalevalue = 0.7
secondphasestarttimesim = 15.5 # CHANGE MANUALLY
myplot <- ggplot(graphdata4) +
  geom_point(data=graphdata6, aes(dev_time, y),
             color = "black", size=0.1, shape=19,alpha=1) +
  geom_errorbar(data=WTs_lifetime,aes(dev_time+16,ymin=(mean_life-sd_life), ymax=(mean_life+sd_life), color=movie),alpha=0.6,size=0.6,width=32.2/40) +
  geom_point(data=WTs_lifetime,aes(dev_time+16,mean_life,color=movie),size=0.6, alpha=0.6,) +
  geom_ribbon(data=graphdata4 %>% filter(dev_time < 12.5), aes(x=dev_time, ymin=(y-y_sd), ymax=(y+y_sd)),
             fill = "grey35", alpha=0.2, linetype="dotted", size=0) +
  geom_line(data=graphdata4 %>% filter(dev_time < 12.5), aes(dev_time, y),
              color = "grey35", size=0.8) +
  geom_ribbon(data=graphdata4 %>% filter(dev_time > 14.7), aes(x=dev_time, ymin=(y-y_sd), ymax=(y+y_sd)),
              fill = "black", alpha=0.6, linetype="dotted", size=0) +
  geom_line(data=graphdata4 %>% filter(dev_time > 14.7), aes(dev_time, y),
            color = "grey35", size=0.8) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.2), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  #geom_line(data=graphdata3, aes(dev_time,y), size=3, color="black") + 
  scale_color_manual(values=movieColors) +
  #scale_fill_manual(values=movieColors) +
  guides(color = guide_legend(nrow = 2)) +
  xlab("Time (hAPF)")+
  #xlim(0,32) + 
  #ylim(0,8) +
  ylab(expression(paste("Cell lifetime (h)")))  +
  scale_y_continuous(limits=c(0,8.2), expand = c(0,0)) +
  scale_x_continuous(limits=c(0,32.2), breaks= seq(0, 32, 4), expand = c(0,0), labels = every_nth(seq(0, 32, 4), 2, inverse = TRUE)) +
  coord_fixed()
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("cell_cycle_time_exp_sim1.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## DON'T NEED STATISTICAL VERSION FOR THIS
## DON'T NEED STATISTICAL VERSION FOR THIS


# 103*0.6

# pdf("cell_cycle_time_exp_sim1.pdf",width = 6, height = 6)
# print(myplot)
# dev.off()

## GS REQUEST EXTRA: add ana f early lifetime data to this somehow. maybe just add them as individual data spots with their start time and lifetime (convert from minutes etc.)
# saved them in Figure 3 folder in PAPER etc. load them in here.
ana_early_lifetimes <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Other/JJW_Simulations_previously_Fig3/list_early_birthtime_lifetime_minutes.csv",header=FALSE, sep = "\t")
ggplot(data=ana_early_lifetimes,aes(V1/60)) +
  geom_histogram(bins=20,color="black") +
  #xlim(0,12) +
  xlab("TTD (h)") +
  ylab("Histogram count") +
  xlim(0,NA) +
  scale_fill_manual(values=c("anterior"="green", "posterior"="red")) +
  theme(text = element_text(size = 18), panel.grid.minor = element_blank()) 

# hmm this is okay but do I need to modify the lifetimes used in simulation to reflect some kind of average of the WTs? but they are time-shifted so hmm.

# so now let's maybe try to make a cubic curve or something that fits through the experimental lifetimes (combined from all WTs)
# during the time window where that data is. 
# the WT (time-aligned) lifetime data ranges from: 1.0417 to 14.333 (plus 16)
# try fitting a second degree polynomial. JJW CHANGING 6 FEB 2020: no reason to only have one 'dip' as it were, 2nd order polynomial doesn't really fit at start. 
x <- as.array(WTs_lifetime$dev_time+16)
y <- as.array(WTs_lifetime$mean_life)
fit2 <- lm(y~poly(x,3,raw=TRUE))   #THIRD ORDER POLYNOMIAL INSTEAD #fit2 <- lm(y~poly(x,2,raw=TRUE))
# okay so that works. now output to a csv.
xx <- seq(16,30, length=50)
plot(x,y,pch=19)
lines(xx, predict(fit2, data.frame(x=xx)), col="green")
##
fit_output <- data.frame(xx)
temp <- data.frame(predict(fit2, data.frame(x=xx)))
fit_output$y <- temp
names(fit_output)[1] <- "x"
names(fit_output)[2] <- "y" # doesn't work to rename for some reason.
fit_output <- as.data.frame(fit_output)
write.csv(fit_output,file="fit_output.csv") # this is not working at allllll WTF. just manually alter the csv. 
## hmmm damn. I really need the STD DEV OF THE LIFETIME as well, damn.

## 6 FEB 2020 -- don't need this anymore, we used a fixed CV. do it anyway to have the data
x <- as.array(WTs_lifetime$dev_time)
y <- as.array(WTs_lifetime$sd_life)
fit2 <- lm(y~poly(x,3,raw=TRUE)) # third order now
# okay so that works. now output to a csv.
xx <- seq(0,14, length=50)
plot(x,y,pch=19)
lines(xx, predict(fit2, data.frame(x=xx)), col="green")
##
fit_output <- data.frame(xx)
temp <- data.frame(predict(fit2, data.frame(x=xx)))
fit_output$y <- temp
names(fit_output)[1] <- "x"
names(fit_output)[2] <- "y" # doesn't work to rename for some reason.
fit_output <- as.data.frame(fit_output)
write.csv(fit_output,file="fit_sd_output.csv")

### PANEL 3) number of cells of different type post 16-h (but potentially include all)
## start with the number of cells in noborder and calculate a mean initial value for that to use for the simulation.

## cellnumber noborder . BUT! i want to do this as a relative value to some chosen value. since the size is arbitrary.
## set the normalisation to be the value at the first COMMON FRAME, which is an ADJUSTED frame of 69. 
## JJW 18 MARCH. WE CHANGED OFFSETSthis isn't affected by the change of offsets by a common amount (so WT1 is frame 0.) and so on
WT1_fr69 <- 207
WT2_fr69 <- 179
WT3_fr69 <- 135
WT4_fr69 <- 196

## JJW 18 MAY 2020. Need to modify so that SOP and quiescent number are just treated in same way as noborder number
## not this weird proportionality thing. 
# Actually No...: solution is to multiply SOP fraction by 
## the dimensionless value of noborder number that is used for the spread calc.
## what that actually means is just that your normalise the SOP count by the total noborder size in fr69.

WT1_number_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/cellnumber_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT1_number_noborder <- WT1_number_noborder %>% select(frame, n) %>% mutate(frame = frame+offset_WT1) %>% mutate(movie = "WT1", n = n/WT1_fr69) %>% select(frame,n,movie)
WT2_number_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/cellnumber_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT2_number_noborder <- WT2_number_noborder %>% select(frame,n) %>% mutate(frame = frame+offset_WT2) %>% mutate(movie = "WT2", n = n/WT2_fr69) %>% select(frame,n,movie)
WT3_number_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/cellnumber_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT3_number_noborder <- WT3_number_noborder %>% select(frame,n) %>% mutate(frame = frame+offset_WT3) %>% mutate(movie = "WT3", n = n/WT3_fr69) %>% select(frame,n,movie)
WT4_number_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/cellnumber_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT4_number_noborder <- WT4_number_noborder %>% select(frame,n) %>% mutate(frame = frame+offset_WT4) %>% mutate(movie = "WT4", n = n/WT4_fr69) %>% select(frame,n,movie)

WT1_number_noborder <- WT1_number_noborder %>% mutate(raw_frame = frame - offset_WT1, raw_number = n*WT1_fr69)
WT2_number_noborder <- WT2_number_noborder %>% mutate(raw_frame = frame - offset_WT2, raw_number = n*WT2_fr69)
WT3_number_noborder <- WT3_number_noborder %>% mutate(raw_frame = frame - offset_WT3, raw_number = n*WT3_fr69)
WT4_number_noborder <- WT4_number_noborder %>% mutate(raw_frame = frame - offset_WT4, raw_number = n*WT4_fr69)

## insert: plot of time-aligned noborder cell number

myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_line(data=WT1_number_noborder, aes(16+frame*2.5/60,n*WT1_fr69),color = "blue", size=0.8) + 
  geom_line(data=WT2_number_noborder, aes(16+frame*2.5/60,n*WT2_fr69),color = "gold", size=0.8) + 
  geom_line(data=WT3_number_noborder, aes(16+frame*2.5/60,n*WT3_fr69),color = "green", size=0.8) + 
  geom_line(data=WT4_number_noborder, aes(16+frame*2.5/60,n*WT4_fr69),color = "red", size=0.8) + 
  xlab("Time (hAPF)")+
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylab(expression(paste("Cell number noborder (rel.)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("WTs_timealigned_number.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)



## now for these ones: make an average and SD ribbon series.
WTs_number_noborder <- rbind(WT1_number_noborder,WT2_number_noborder,WT3_number_noborder,WT4_number_noborder)
WTs_number_noborder <- WTs_number_noborder %>% group_by(frame) %>% summarise(movies = n(), mean_n = mean(n), sd_n = sd(n)) %>% filter(movies == 4) %>% mutate(dev_time = frame*2.5/60)
## so now this contains the proportion of the movie_specific number at real_adjusted_frame = 69. 
## convert back to number by multiplying by the average of the final values in each WT.
conversion <- mean(c(WT1_fr69,WT2_fr69,WT3_fr69,WT4_fr69))
WTs_number_noborder <- WTs_number_noborder %>% mutate(mean_n=mean_n*conversion, sd_n = sd_n*conversion)

myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_line(data=WT1_number_noborder, aes(16+frame*2.5/60,n*conversion),color = "blue", size=0.8) + 
  geom_line(data=WT2_number_noborder, aes(16+frame*2.5/60,n*conversion),color = "gold", size=0.8) + 
  geom_line(data=WT3_number_noborder, aes(16+frame*2.5/60,n*conversion),color = "green", size=0.8) + 
  geom_line(data=WT4_number_noborder, aes(16+frame*2.5/60,n*conversion),color = "red", size=0.8) + 
  xlab("Time (hAPF)")+
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylab(expression(paste("Cell number noborder (rel.)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("WTs_timealigned_number_renormalised_comparetogs.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)
  
## cellnumber SOPs.
WT1_SOP_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/cumul_counts/count_SOP_noborder.csv",header=TRUE) %>% na.omit() %>% mutate
# mutate to offset dev_time
WT1_SOP_noborder <- WT1_SOP_noborder %>% select(frame,count) %>% mutate(frame = frame + (offset_WT1), n = count) %>% select(frame,n) %>% mutate(movie = "WT1")
WT1_SOP_noborder <- WT1_SOP_noborder %>% mutate(n=n/WT1_fr69)
# extra bits. nstar above.  


WT2_SOP_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/cumul_counts/count_SOP_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT2_SOP_noborder <- WT2_SOP_noborder %>% select(frame,count) %>% mutate(frame = frame + (offset_WT2), n = count) %>% select(frame,n) %>% mutate(movie = "WT2")
WT2_SOP_noborder <- WT2_SOP_noborder %>% mutate(n=n/WT2_fr69)

WT3_SOP_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/cumul_counts/count_SOP_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT3_SOP_noborder <- WT3_SOP_noborder %>% select(frame,count) %>% mutate(frame = frame + (offset_WT3), n = count) %>% select(frame,n) %>% mutate(movie = "WT3")
WT3_SOP_noborder <- WT3_SOP_noborder %>% mutate(n=n/WT3_fr69)

WT4_SOP_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/cumul_counts/count_SOP_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT4_SOP_noborder <- WT4_SOP_noborder %>% select(frame,count) %>% mutate(frame = frame + (offset_WT4), n = count) %>% select(frame,n) %>% mutate(movie = "WT4")
WT4_SOP_noborder <- WT4_SOP_noborder %>% mutate(n=n/WT4_fr69)

WTs_SOP_noborder <- rbind(WT1_SOP_noborder,WT2_SOP_noborder,WT3_SOP_noborder,WT4_SOP_noborder)
WTs_SOP_noborder <- WTs_SOP_noborder %>% group_by(frame) %>% summarise(movies = n(), mean_n = mean(n), sd_n = sd(n)) %>% filter(movies == 4) %>% mutate(dev_time = frame*2.5/60)

#convert to real number by multiplying by the conversion factor from before
WTs_SOP_noborder <- WTs_SOP_noborder %>% mutate(mean_n=mean_n*conversion, sd_n = sd_n*conversion)

## cellnumber QUIESCENT. 

WT1_dropout_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/count_dropout_noborder.csv",header=TRUE) %>% na.omit() %>% select(-X)
#pad from 0 to start.
pad <- data.frame(seq(0,149))
colnames(pad) <- "frame"
pad$dev_time <- pad$frame*2.5/60
pad$count <- 0
WT1_dropout_noborder <- WT1_dropout_noborder %>% rbind(pad) %>% arrange(frame)
# mutate to offset dev_time
WT1_dropout_noborder <- WT1_dropout_noborder %>% select(frame,count) %>% mutate(frame = frame + (offset_WT1), n = count) %>% select(frame,n) %>% mutate(movie = "WT1")
WT1_dropout_noborder <- WT1_dropout_noborder %>% mutate(n=n/WT1_fr69)

WT2_dropout_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/count_dropout_noborder.csv",header=TRUE) %>% na.omit() %>% select(-X)
#pad from 0 to start.
pad <- data.frame(seq(0,216))
colnames(pad) <- "frame"
pad$dev_time <- pad$frame*2.5/60
pad$count <- 0
WT2_dropout_noborder <- WT2_dropout_noborder %>% rbind(pad) %>% arrange(frame)
# mutate to offset dev_time
WT2_dropout_noborder <- WT2_dropout_noborder %>% select(frame,count) %>% mutate(frame = frame + (offset_WT2), n = count) %>% select(frame,n) %>% mutate(movie = "WT2")
WT2_dropout_noborder <- WT2_dropout_noborder %>% mutate(n=n/WT2_fr69)

WT3_dropout_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/count_dropout_noborder.csv",header=TRUE) %>% na.omit() %>% select(-X)
#pad from 0 to start.
pad <- data.frame(seq(0,158))
colnames(pad) <- "frame"
pad$dev_time <- pad$frame*2.5/60
pad$count <- 0
WT3_dropout_noborder <- WT3_dropout_noborder %>% rbind(pad) %>% arrange(frame)
# mutate to offset dev_time
WT3_dropout_noborder <- WT3_dropout_noborder %>% select(frame,count) %>% mutate(frame = frame + (offset_WT3), n = count) %>% select(frame,n) %>% mutate(movie = "WT3")
WT3_dropout_noborder <- WT3_dropout_noborder %>% mutate(n=n/WT3_fr69)

WT4_dropout_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/count_dropout_noborder.csv",header=TRUE) %>% na.omit() %>% select(-X)
#pad from 0 to start.
pad <- data.frame(seq(0,177))
colnames(pad) <- "frame"
pad$dev_time <- pad$frame*2.5/60
pad$count <- 0
WT4_dropout_noborder <- WT4_dropout_noborder %>% rbind(pad) %>% arrange(frame)
# mutate to offset dev_time
WT4_dropout_noborder <- WT4_dropout_noborder %>% select(frame,count) %>% mutate(frame = frame + (offset_WT4), n = count) %>% select(frame,n) %>% mutate(movie = "WT4")
WT4_dropout_noborder <- WT4_dropout_noborder %>% mutate(n=n/WT4_fr69)

WTs_dropout_noborder <- rbind(WT1_dropout_noborder,WT2_dropout_noborder,WT3_dropout_noborder,WT4_dropout_noborder)
WTs_dropout_noborder <- WTs_dropout_noborder %>% group_by(frame) %>% summarise(movies = n(), mean_n = mean(n), sd_n = sd(n)) %>% filter(movies == 4) %>% mutate(dev_time = frame*2.5/60)

#convert to real number by multiplying by conversion from before
WTs_dropout_noborder <- WTs_dropout_noborder %>% mutate(mean_n=mean_n*conversion, sd_n = sd_n*conversion)


## now combine data for normalised noborder number, SOP count and dropout count.
WTs_number_noborder$series = "noborder"
WTs_SOP_noborder$series = "SOP"

WTs_dropout_noborder$series = "quiescent"

WTs_celltypes_number <- rbind(WTs_number_noborder,WTs_SOP_noborder,WTs_dropout_noborder)

# # try plotting the ribbons
# myplot <- ggplot(WTs_celltypes_number) +
#   geom_ribbon(data=WTs_celltypes_number, aes(x=dev_time+16, ymin=(mean_n-sd_n), ymax=(mean_n+sd_n),fill=series),
#               alpha=0.4, linetype="dotted", size=2) +
#   theme(legend.direction="vertical",legend.position="none", 
#         legend.title = element_blank(), aspect.ratio=2/3, 
#         text = element_text(size = 10), panel.grid.major.x = element_blank(), 
#         panel.grid.minor.x = element_blank(),
#         panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
#         axis.line = element_line(colour = "black",size=0.6), 
#         panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
#         axis.text=element_text(size=10, colour = "black"), 
#         legend.text=element_text(size=10, colour = "black"), 
#         axis.ticks=element_line(size=0.6,colour="black")) +
#   #geom_errorbar(data=WTs_lifetime,aes(dev_time+16,ymin=(mean_life-sd_life), ymax=(mean_life+sd_life), color=movie),size=2,width=2) +
#   #geom_point(data=WTs_lifetime,aes(dev_time+16,mean_life,color=movie),size=3) +
#   #geom_line(data=graphdata3, aes(dev_time,y), size=3, color="black") + 
#   #scale_color_manual(values=movieColors) +
#   #scale_fill_manual(values=movieColors) +
#   xlab("Time (hAPF)")+
#   scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
#   ylab(expression(paste("Cell number noborder (rel.)"))) 
# #scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
# myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
#                          height = unit(39*2/3, "mm"))
# ggsave("celltypes_number.pdf", plot = myplot, device="pdf",
#        scale=1, width = 103*0.55, height=103*0.55, units = "mm",
#        dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)


## looking good. now want to get in the simulation numbers. 
sim_number_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/nb_cells_second_phase_no_border_all_types_run_0.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_number_noborder) <- c("dev_time", "n")
sim_number_noborder$series <- "noborder"

sim_quiescent_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/nb_cells_second_phase_no_border_arrested_cells_run_0.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_quiescent_noborder) <- c("dev_time", "n")
sim_quiescent_noborder$series <- "quiescent"

sim_SOP_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/nb_cells_second_phase_no_border_SOPs_run_0.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_SOP_noborder) <- c("dev_time", "n")
sim_SOP_noborder$series <- "SOP"

myplot <- ggplot(WTs_celltypes_number) +
  geom_ribbon(data=WTs_celltypes_number, aes(x=dev_time+16, ymin=(mean_n-sd_n), ymax=(mean_n+sd_n),fill=series),
              alpha=0.4, linetype="dotted", size=0.8) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_line(data=sim_number_noborder, aes(dev_time,n,color=series), size=0.8) + 
  geom_line(data=sim_quiescent_noborder, aes(dev_time,n,color=series), size=0.8) + 
  geom_line(data=sim_SOP_noborder, aes(dev_time,n,color=series), size=0.8) + 
  scale_color_manual(values=c("noborder" = "darkgreen","quiescent"="red","SOP"="blue")) +
  scale_fill_manual(values=c("noborder" = "darkgreen","quiescent"="red","SOP"="blue")) +
  xlab("Time (hAPF)")+
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylab(expression(paste("Cell number noborder (rel.)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("celltypes_number.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## STATISTICAL VERSION 19 APRIL 2020: do as above but with a modified simulation read in that takes the multiple runs in
## borrow code from starat16h_statistical.R. 
for (i in seq(0,N_RUNS-1)) {
  # noborder number
  filename = gsub(" \\d ", paste(i), paste("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/nb_cells_second_phase_no_border_all_types_run_",i,".csv",sep=""))
  temp <- read.csv(filename,header=FALSE, sep= " ") %>% na.omit() 
  colnames(temp) <- c("dev_time", "n")
  temp$series <- "noborder"
  temp$run <- i
  if (i == 0)  {
    sim_statistical_noborder <- temp
  } else {
    sim_statistical_noborder <- rbind(sim_statistical_noborder,temp)  
  }
  
  # QUIESCENT number
  filename = gsub(" \\d ", paste(i), paste("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/nb_cells_second_phase_no_border_arrested_cells_run_",i,".csv",sep=""))
  temp <- read.csv(filename,header=FALSE, sep= " ") %>% na.omit() 
  colnames(temp) <- c("dev_time", "n")
  temp$series <- "quiescent"
  temp$run <- i
  if (i == 0)  {
    sim_statistical_quiescent <- temp
  } else {
    sim_statistical_quiescent <- rbind(sim_statistical_quiescent,temp)  
  }
  
  # SOP number
  filename = gsub(" \\d ", paste(i), paste("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/nb_cells_second_phase_no_border_SOPs_run_",i,".csv",sep=""))
  temp <- read.csv(filename,header=FALSE, sep= " ") %>% na.omit() 
  colnames(temp) <- c("dev_time", "n")
  temp$series <- "SOP"
  temp$run <- i
  if (i == 0)  {
    sim_statistical_SOP <- temp
  } else {
    sim_statistical_SOP <- rbind(sim_statistical_SOP,temp)  
  }
  
}
sim_statistical_number_separateruns <- sim_statistical_noborder

sim_statistical_noborder <- sim_statistical_noborder %>% group_by(dev_time) %>% summarise(mean = mean(n),sd = sd(n), series="noborder")
sim_statistical_quiescent <- sim_statistical_quiescent %>% group_by(dev_time) %>% summarise(mean = mean(n),sd = sd(n), series="quiescent")
sim_statistical_SOP <- sim_statistical_SOP %>% group_by(dev_time) %>% summarise(mean = mean(n),sd = sd(n), series="SOP")

myplot <- ggplot(WTs_celltypes_number) +
  geom_ribbon(data=WTs_celltypes_number, aes(x=dev_time+16, ymin=(mean_n-sd_n), ymax=(mean_n+sd_n),fill=series),
              alpha=0.3, linetype="dotted", size=0.8) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_ribbon(data=sim_statistical_noborder,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series,color=series),size=0.25, alpha=0.5) + 
  geom_ribbon(data=sim_statistical_quiescent,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series,color=series),size=0.25, alpha=0.5) + 
  geom_ribbon(data=sim_statistical_SOP,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series),size=0, alpha=0.5) + 
  geom_line(data=sim_statistical_noborder, aes(dev_time,mean,color=series), size=0.5) + 
  geom_line(data=sim_statistical_quiescent, aes(dev_time,mean,color=series), size=0.5) + 
  geom_line(data=sim_statistical_SOP, aes(dev_time,mean,color=series), size=0.3) + 
  scale_color_manual(values=c("noborder" = "darkgreen","quiescent"="red","SOP"="blue")) +
  scale_fill_manual(values=c("noborder" = "darkgreen","quiescent"="red","SOP"="blue")) +
  xlab("Time (hAPF)")+
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylab(expression(paste("Cell number noborder (rel.)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("STATISTICAL_celltypes_number.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## END STATISTICAL ADDITION

### INSERT -- VERSION WITHOUT EXPT FOR GS SLIDES:
myplot <- ggplot() +
  #geom_ribbon(data=WTs_celltypes_number, aes(x=dev_time+16, ymin=(mean_n-sd_n), ymax=(mean_n+sd_n),fill=series),
  #            alpha=0.3, linetype="dotted", size=0.8) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_ribbon(data=sim_statistical_noborder,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series,color=series),size=0.25, alpha=0.5) + 
  geom_ribbon(data=sim_statistical_quiescent,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series,color=series),size=0.25, alpha=0.5) + 
  geom_ribbon(data=sim_statistical_SOP,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series),size=0, alpha=0.5) + 
  geom_line(data=sim_statistical_noborder, aes(dev_time,mean,color=series), size=0.5) + 
  geom_line(data=sim_statistical_quiescent, aes(dev_time,mean,color=series), size=0.5) + 
  geom_line(data=sim_statistical_SOP, aes(dev_time,mean,color=series), size=0.3) + 
  scale_color_manual(values=c("noborder" = "darkgreen","quiescent"="red","SOP"="blue")) +
  scale_fill_manual(values=c("noborder" = "darkgreen","quiescent"="red","SOP"="blue")) +
  xlab("Time (hAPF)")+
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylab(expression(paste("Cell number noborder (rel.)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("STATISTICAL_celltypes_number_onlysimforgs.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

### INSERT EXP ONLY FOR GS TALK
myplot <- ggplot(WTs_celltypes_number) +
  geom_ribbon(data=WTs_celltypes_number, aes(x=dev_time+16, ymin=(mean_n-sd_n), ymax=(mean_n+sd_n),fill=series),
              alpha=0.6, linetype="dotted", size=0.8) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  #geom_ribbon(data=sim_statistical_noborder,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series,color=series),size=0.25, alpha=0.5) + 
  #geom_ribbon(data=sim_statistical_quiescent,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series,color=series),size=0.25, alpha=0.5) + 
  #geom_ribbon(data=sim_statistical_SOP,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series),size=0, alpha=0.5) + 
  #geom_line(data=sim_statistical_quiescent, aes(dev_time,mean,color=series), size=0.5) + 
  #geom_line(data=sim_statistical_noborder, aes(dev_time,mean,color=series), size=0.5) + 
  #geom_line(data=sim_statistical_SOP, aes(dev_time,mean,color=series), size=0.3) + 
  scale_color_manual(values=c("noborder" = "darkgreen","quiescent"="red","SOP"="blue")) +
  scale_fill_manual(values=c("noborder" = "darkgreen","quiescent"="red","SOP"="blue")) +
  xlab("Time (hAPF)")+
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylab(expression(paste("Cell number noborder (rel.)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("STATISTICAL_celltypes_number_exponlyforGS.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)
### END INSERT


## FINAL PANEL:  CELL DIVISION RATE. Think I can grab in the experimental data from that other panel in another figure (2?) and then mash it together to make the ribbon.
# however.. the ribbon/averaging together thing will ruin the division rate oscillations in the experiment data.
# so maybe show that panel (again??) and make a separate panel just showing the simulation data? hmmm. 

# anyway first load in simulation division rate. 
sim_div_rate_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/kd_array_no_border_smoothed_run_0.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_div_rate_noborder ) <- c("dev_time", "rate")

## JJW INSERT: borrowing code from startat16h_statistical_useexpSD.R to recalculate division rate in simulation see also below
## in the for loop.




## perhaps add the experimental ones in half transparent.
avgIsoDefRateSummary_WT1 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT1$frame <- round(avgIsoDefRateSummary_WT1$dev_time*60/2.5)
avgIsoDefRateSummary_WT1$realframe <- avgIsoDefRateSummary_WT1$frame + offset_WT1
avgIsoDefRateSummary_WT1$realdev_time <- avgIsoDefRateSummary_WT1$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT1$roi <- as.character(avgIsoDefRateSummary_WT1$roi)
avgIsoDefRateSummary_WT1$isoContrib <- as.character(avgIsoDefRateSummary_WT1$isoContrib)
#
avgIsoDefRateSummary_WT2 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT2$frame <- round(avgIsoDefRateSummary_WT2$dev_time*60/2.5)
avgIsoDefRateSummary_WT2$realframe <- avgIsoDefRateSummary_WT2$frame + offset_WT2
avgIsoDefRateSummary_WT2$realdev_time <- avgIsoDefRateSummary_WT2$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT2$roi <- as.character(avgIsoDefRateSummary_WT2$roi)
avgIsoDefRateSummary_WT2$isoContrib <- as.character(avgIsoDefRateSummary_WT2$isoContrib)
#
avgIsoDefRateSummary_WT3 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT3$frame <- round(avgIsoDefRateSummary_WT3$dev_time*60/2.5)
avgIsoDefRateSummary_WT3$realframe <- avgIsoDefRateSummary_WT3$frame + offset_WT3
avgIsoDefRateSummary_WT3$realdev_time <- avgIsoDefRateSummary_WT3$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT3$roi <- as.character(avgIsoDefRateSummary_WT3$roi)
avgIsoDefRateSummary_WT3$isoContrib <- as.character(avgIsoDefRateSummary_WT3$isoContrib)
#
avgIsoDefRateSummary_WT4 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT4$frame <- round(avgIsoDefRateSummary_WT4$dev_time*60/2.5)
avgIsoDefRateSummary_WT4$realframe <- avgIsoDefRateSummary_WT4$frame + offset_WT4
avgIsoDefRateSummary_WT4$realdev_time <- avgIsoDefRateSummary_WT4$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT4$roi <- as.character(avgIsoDefRateSummary_WT4$roi)
avgIsoDefRateSummary_WT4$isoContrib <- as.character(avgIsoDefRateSummary_WT4$isoContrib)

# frames data to calculate min and max real frame to have
load("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/frames.RData")
frames_WT1 <- frames
load("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/frames.RData")
frames_WT2 <- frames
load("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/frames.RData")
frames_WT3 <- frames
load("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/frames.RData")
frames_WT4 <- frames


max_realframe_WT1 <- max(frames_WT1$frame) + offset_WT1
max_realframe_WT2 <- max(frames_WT2$frame) + offset_WT2
max_realframe_WT3 <- max(frames_WT3$frame) + offset_WT3
max_realframe_WT4 <- max(frames_WT4$frame) + offset_WT4
min_realframe_WT1 <- min(frames_WT1$frame) + offset_WT1
min_realframe_WT2 <- min(frames_WT2$frame) + offset_WT2
min_realframe_WT3 <- min(frames_WT3$frame) + offset_WT3
min_realframe_WT4 <- min(frames_WT4$frame) + offset_WT4

max_realframe <- min(c(max_realframe_WT1,max_realframe_WT2,max_realframe_WT3,max_realframe_WT4)) - 1
min_realframe <- max(c(min_realframe_WT1,min_realframe_WT2,min_realframe_WT3,min_realframe_WT4)) + 1


## %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Combined RATE contribs for given isoContrib (division here) from different WTs. USING REALDEV_TIME
## IE OFFSET DATA. 
avgIsoDefRateSummary_allWTs_division <- rbind(avgIsoDefRateSummary_WT1 %>% filter(realframe >= min_realframe & realframe <= max_realframe) %>% filter(isoContrib=="division") %>% mutate(movie = "WT1"), avgIsoDefRateSummary_WT2 %>% filter(realframe >= min_realframe & realframe <= max_realframe) %>% filter(isoContrib=="division") %>% mutate(movie = "WT2"),
                                              avgIsoDefRateSummary_WT3 %>% filter(realframe >= min_realframe & realframe <= max_realframe) %>% filter(isoContrib=="division") %>% mutate(movie = "WT3"), avgIsoDefRateSummary_WT4 %>% filter(realframe >= min_realframe & realframe <= max_realframe) %>% filter(isoContrib=="division") %>% mutate(movie = "WT4"))


#NEXT: put the WT experimental data in the background for the division rate plot. 

# NEED TO CHANGE THIS -- use greater smoothing kernel for the experimental data and match it to the simulation value.
myplot <- ggplot(sim_div_rate_noborder) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_line(data=avgIsoDefRateSummary_allWTs_division, aes(realdev_time + 16, value.avg, color=movie),size=0.8,alpha=0.75)+
  geom_line(data=sim_div_rate_noborder, aes(dev_time,rate), size=0.8, color="grey35") + 
  scale_color_manual(values=movieColors) +
  scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylim(0,0.4) +
  xlab("Time (hAPF)")+
  ylab(expression(paste("Rate (hr"^"-1",")"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("sim_div_rate.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## STATISTICAL -- DONT NEED TO DO THIS FOR DIV RATE BUT INSTEAD
## NEED TO DO FOURIER STUFF. FOURIER DIV RATE SECTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
library("stats")
for (i in seq(0,N_RUNS-1)) {
  # noborder number
  filename = gsub(" \\d ", paste(i), paste("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/kd_array_no_border_smoothed_run_",i,".csv",sep=""))
  temp <- read.csv(filename,header=FALSE, sep= " ") %>% na.omit() 
  colnames(temp) <- c("dev_time", "rate")
  temp$series <- "div_rate"
  temp$run <- i
  if (i == 0)  {
    sim_statistical_div_rate <- temp
  } else {
    sim_statistical_div_rate <- rbind(sim_statistical_div_rate,temp)  
  }
  
  filename = gsub(" \\d ", paste(i), paste("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/divs_frame_array_run_",i,".csv",sep=""))
  temp <- read.csv(filename,header=FALSE, sep= " ") %>% na.omit() 
  colnames(temp) <- c("dev_time", "divs")
  temp$run <- i
  if (i == 0)  {
    sim_divs_frame_array <- temp
  } else {
    sim_divs_frame_array <- rbind(sim_divs_frame_array,temp)  
  }
}

timeinthr <- 0.04167
kernSize <- 21
recalc_div_rate <- sim_divs_frame_array %>% dt.merge(sim_statistical_number_separateruns,by=c("run","dev_time"))
recalc_div_rate <- recalc_div_rate %>% mutate(rate = divs/(n*(2.5/60)))
#smooth
recalc_div_rate <- recalc_div_rate %>% group_by(run) %>% mutate(rate = ma(rate,kernSize)) %>% na.omit()
# use this instead of the previous. i.e. it weill be autoatmically used in fourier too.
sim_statistical_div_rate_noborder <- recalc_div_rate


### KS1 VERSION
timeinthr <- 0.04167
kernSize <- 1
ks1_recalc_div_rate <- sim_divs_frame_array %>% dt.merge(sim_statistical_number_separateruns,by=c("run","dev_time"))
ks1_recalc_div_rate <- ks1_recalc_div_rate %>% mutate(rate = divs/(n*(2.5/60)))
#smooth
ks1_recalc_div_rate <- ks1_recalc_div_rate %>% group_by(run) %>% mutate(rate = ma(rate,kernSize)) %>% na.omit()
# use this instead of the previous. i.e. it weill be autoatmically used in fourier too.
ks1_sim_statistical_div_rate_noborder <- ks1_recalc_div_rate
### KS1 VERSION


## Use RUN0 to output a real-space division rate
myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_line(data=avgIsoDefRateSummary_allWTs_division, aes(realdev_time + 16, value.avg, color=movie),size=0.8,alpha=0.75)+
  geom_line(data=sim_statistical_div_rate_noborder %>% filter(run == 0), aes(dev_time,rate), size=0.8, color="grey35") + 
  scale_color_manual(values=movieColors) +
  scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylim(0,0.4) +
  xlab("Time (hAPF)")+
  ylab(expression(paste("Rate (hr"^"-1",")"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("sim_div_rate_recalc_run0.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)


### INSERT WITHOUT EXPT DATA, FOR GS
myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  #geom_line(data=avgIsoDefRateSummary_allWTs_division, aes(realdev_time + 16, value.avg, color=movie),size=0.8,alpha=0.75)+
  geom_line(data=sim_statistical_div_rate_noborder %>% filter(run == 0), aes(dev_time,rate), size=0.8, color="grey35") + 
  scale_color_manual(values=movieColors) +
  scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylim(0,0.4) +
  xlab("Time (hAPF)")+
  ylab(expression(paste("Rate (hr"^"-1",")"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("sim_div_rate_recalc_run0_simonlyforGS.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

### END INSERT

### INSERT EXPT ONLY FOR GS
myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_line(data=avgIsoDefRateSummary_allWTs_division, aes(realdev_time + 16, value.avg, color=movie),size=0.8,alpha=0.75)+
  #geom_line(data=sim_statistical_div_rate_noborder %>% filter(run == 0), aes(dev_time,rate), size=0.8, color="grey35") + 
  scale_color_manual(values=movieColors) +
  scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylim(0,0.4) +
  xlab("Time (hAPF)")+
  ylab(expression(paste("Rate (hr"^"-1",")"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("sim_div_rate_recalc_run0_exponlyforGS.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

### INSERT END





## FOURIER SECTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cutoff_sim <- 28.5
cutoff_lower_sim <- 17.0
timespacing_sim <- 2.5/60 

sim_fourier <- ks1_sim_statistical_div_rate_noborder %>% filter(dev_time < cutoff_sim & dev_time > cutoff_lower_sim) %>% group_by(run) %>%
  summarise(value = list(abs(fft(rate))), row = list(seq.int(n())), N = n()) %>%
  unnest() %>% mutate(freq = (row-1)*(1/timespacing_sim)/N  )
# then I guess average over runs
sim_fourier <- sim_fourier %>% group_by(run) %>% mutate(value = value / max(value)) %>% ungroup()
sim_fourier <- sim_fourier %>% group_by(row) %>% summarise(freq=mean(freq), absfft=mean(value), sdabsfft=sd(value), movie="sim")

## GET WT FT'd data in. do without cutting off data at either end. not important for Fourier stuff. 
avgIsoDefRateSummary_WT1 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT1$frame <- round(avgIsoDefRateSummary_WT1$dev_time*60/2.5)
avgIsoDefRateSummary_WT1$realframe <- avgIsoDefRateSummary_WT1$frame + offset_WT1
avgIsoDefRateSummary_WT1$realdev_time <- avgIsoDefRateSummary_WT1$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT1$roi <- as.character(avgIsoDefRateSummary_WT1$roi)
avgIsoDefRateSummary_WT1$isoContrib <- as.character(avgIsoDefRateSummary_WT1$isoContrib)
#
avgIsoDefRateSummary_WT2 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT2$frame <- round(avgIsoDefRateSummary_WT2$dev_time*60/2.5)
avgIsoDefRateSummary_WT2$realframe <- avgIsoDefRateSummary_WT2$frame + offset_WT2
avgIsoDefRateSummary_WT2$realdev_time <- avgIsoDefRateSummary_WT2$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT2$roi <- as.character(avgIsoDefRateSummary_WT2$roi)
avgIsoDefRateSummary_WT2$isoContrib <- as.character(avgIsoDefRateSummary_WT2$isoContrib)
#
avgIsoDefRateSummary_WT3 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT3$frame <- round(avgIsoDefRateSummary_WT3$dev_time*60/2.5)
avgIsoDefRateSummary_WT3$realframe <- avgIsoDefRateSummary_WT3$frame + offset_WT3
avgIsoDefRateSummary_WT3$realdev_time <- avgIsoDefRateSummary_WT3$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT3$roi <- as.character(avgIsoDefRateSummary_WT3$roi)
avgIsoDefRateSummary_WT3$isoContrib <- as.character(avgIsoDefRateSummary_WT3$isoContrib)
#
avgIsoDefRateSummary_WT4 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT4$frame <- round(avgIsoDefRateSummary_WT4$dev_time*60/2.5)
avgIsoDefRateSummary_WT4$realframe <- avgIsoDefRateSummary_WT4$frame + offset_WT4
avgIsoDefRateSummary_WT4$realdev_time <- avgIsoDefRateSummary_WT4$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT4$roi <- as.character(avgIsoDefRateSummary_WT4$roi)
avgIsoDefRateSummary_WT4$isoContrib <- as.character(avgIsoDefRateSummary_WT4$isoContrib)


## KS1 version
ks1_avgIsoDefRateSummary_WT1 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/kernSize1/avgIsoDefRateSummary.csv") 
ks1_avgIsoDefRateSummary_WT1$frame <- round(ks1_avgIsoDefRateSummary_WT1$dev_time*60/2.5)
ks1_avgIsoDefRateSummary_WT1$realframe <- ks1_avgIsoDefRateSummary_WT1$frame + offset_WT1
ks1_avgIsoDefRateSummary_WT1$realdev_time <- ks1_avgIsoDefRateSummary_WT1$realframe * 2.5/60
# removing factors (?? what does this do?)
ks1_avgIsoDefRateSummary_WT1$roi <- as.character(ks1_avgIsoDefRateSummary_WT1$roi)
ks1_avgIsoDefRateSummary_WT1$isoContrib <- as.character(ks1_avgIsoDefRateSummary_WT1$isoContrib)
#
ks1_avgIsoDefRateSummary_WT2 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/kernSize1/avgIsoDefRateSummary.csv") 
ks1_avgIsoDefRateSummary_WT2$frame <- round(ks1_avgIsoDefRateSummary_WT2$dev_time*60/2.5)
ks1_avgIsoDefRateSummary_WT2$realframe <- ks1_avgIsoDefRateSummary_WT2$frame + offset_WT2
ks1_avgIsoDefRateSummary_WT2$realdev_time <- ks1_avgIsoDefRateSummary_WT2$realframe * 2.5/60
# removing factors (?? what does this do?)
ks1_avgIsoDefRateSummary_WT2$roi <- as.character(ks1_avgIsoDefRateSummary_WT2$roi)
ks1_avgIsoDefRateSummary_WT2$isoContrib <- as.character(ks1_avgIsoDefRateSummary_WT2$isoContrib)
#
ks1_avgIsoDefRateSummary_WT3 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/kernSize1/avgIsoDefRateSummary.csv") 
ks1_avgIsoDefRateSummary_WT3$frame <- round(ks1_avgIsoDefRateSummary_WT3$dev_time*60/2.5)
ks1_avgIsoDefRateSummary_WT3$realframe <- ks1_avgIsoDefRateSummary_WT3$frame + offset_WT3
ks1_avgIsoDefRateSummary_WT3$realdev_time <- ks1_avgIsoDefRateSummary_WT3$realframe * 2.5/60
# removing factors (?? what does this do?)
ks1_avgIsoDefRateSummary_WT3$roi <- as.character(ks1_avgIsoDefRateSummary_WT3$roi)
ks1_avgIsoDefRateSummary_WT3$isoContrib <- as.character(ks1_avgIsoDefRateSummary_WT3$isoContrib)
#
ks1_avgIsoDefRateSummary_WT4 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/kernSize1/avgIsoDefRateSummary.csv") 
ks1_avgIsoDefRateSummary_WT4$frame <- round(ks1_avgIsoDefRateSummary_WT4$dev_time*60/2.5)
ks1_avgIsoDefRateSummary_WT4$realframe <- ks1_avgIsoDefRateSummary_WT4$frame + offset_WT4
ks1_avgIsoDefRateSummary_WT4$realdev_time <- ks1_avgIsoDefRateSummary_WT4$realframe * 2.5/60
# removing factors (?? what does this do?)
ks1_avgIsoDefRateSummary_WT4$roi <- as.character(ks1_avgIsoDefRateSummary_WT4$roi)
ks1_avgIsoDefRateSummary_WT4$isoContrib <- as.character(ks1_avgIsoDefRateSummary_WT4$isoContrib)
##

for_fourier_div_rate_WT1 <- ks1_avgIsoDefRateSummary_WT1 %>% filter(isoContrib == "division")
for_fourier_div_rate_WT2 <- ks1_avgIsoDefRateSummary_WT2 %>% filter(isoContrib == "division") 
for_fourier_div_rate_WT3 <- ks1_avgIsoDefRateSummary_WT3 %>% filter(isoContrib == "division")
for_fourier_div_rate_WT4 <- ks1_avgIsoDefRateSummary_WT4 %>% filter(isoContrib == "division")

cutofftime <- 28.5-16
lowercutofftime <- 17.0-16.0
for_fourier_div_rate_WT1 <- for_fourier_div_rate_WT1 %>% filter(dev_time < cutofftime, dev_time > lowercutofftime)
for_fourier_div_rate_WT2 <- for_fourier_div_rate_WT2 %>% filter(dev_time < cutofftime, dev_time > lowercutofftime)
for_fourier_div_rate_WT3 <- for_fourier_div_rate_WT3 %>% filter(dev_time < cutofftime, dev_time > lowercutofftime)
for_fourier_div_rate_WT4 <- for_fourier_div_rate_WT4 %>% filter(dev_time < cutofftime, dev_time > lowercutofftime)
timespacing <- for_fourier_div_rate_WT1[2,4] - for_fourier_div_rate_WT1[1,4]

# use abs() of fft. need to figure out meaning of frequency bins, been a while. be careful to do this right
fourier_div_rate_WT1 <- abs(fft(for_fourier_div_rate_WT1$value.avg))
fourier_div_rate_WT2 <- abs(fft(for_fourier_div_rate_WT2$value.avg))
fourier_div_rate_WT3 <- abs(fft(for_fourier_div_rate_WT3$value.avg))
fourier_div_rate_WT4 <- abs(fft(for_fourier_div_rate_WT4$value.avg))

# convert to data frame and figure out units of x axis of FFT
xunit <- (1/timespacing) / nrow(for_fourier_div_rate_WT1)

fourier_div_rate_WT1 <- data.frame(fourier_div_rate_WT1)
colnames(fourier_div_rate_WT1) <- "absfft"
fourier_div_rate_WT1$row <- seq.int(nrow(fourier_div_rate_WT1))
fourier_div_rate_WT1$movie <- "WT1"
fourier_div_rate_WT1$freq <- (fourier_div_rate_WT1$row-1)*xunit
normWT1 <- (fourier_div_rate_WT1 %>% filter(freq == 0))$absfft 
fourier_div_rate_WT1$absfft <- fourier_div_rate_WT1$absfft/normWT1

fourier_div_rate_WT2 <- data.frame(fourier_div_rate_WT2)
colnames(fourier_div_rate_WT2) <- "absfft"
fourier_div_rate_WT2$row <- seq.int(nrow(fourier_div_rate_WT2))
fourier_div_rate_WT2$movie <- "WT2"
fourier_div_rate_WT2$freq <- (fourier_div_rate_WT2$row-1)*xunit
normWT2 <- (fourier_div_rate_WT2 %>% filter(freq == 0))$absfft 
fourier_div_rate_WT2$absfft <- fourier_div_rate_WT2$absfft/normWT2

fourier_div_rate_WT3 <- data.frame(fourier_div_rate_WT3)
colnames(fourier_div_rate_WT3) <- "absfft"
fourier_div_rate_WT3$row <- seq.int(nrow(fourier_div_rate_WT3))
fourier_div_rate_WT3$movie <- "WT3"
fourier_div_rate_WT3$freq <- (fourier_div_rate_WT3$row-1)*xunit
normWT3 <- (fourier_div_rate_WT3 %>% filter(freq == 0))$absfft 
fourier_div_rate_WT3$absfft <- fourier_div_rate_WT3$absfft/normWT3

fourier_div_rate_WT4 <- data.frame(fourier_div_rate_WT4)
colnames(fourier_div_rate_WT4) <- "absfft"
fourier_div_rate_WT4$row <- seq.int(nrow(fourier_div_rate_WT4))
fourier_div_rate_WT4$movie <- "WT4"
fourier_div_rate_WT4$freq <- (fourier_div_rate_WT4$row-1)*xunit
normWT4 <- (fourier_div_rate_WT4 %>% filter(freq == 0))$absfft 
fourier_div_rate_WT4$absfft <- fourier_div_rate_WT4$absfft/normWT4

fourier_div_rate_all <- rbind(fourier_div_rate_WT1,fourier_div_rate_WT2,fourier_div_rate_WT3,fourier_div_rate_WT4)
fourier_div_rate_avg_exp <- fourier_div_rate_all %>% group_by(row) %>% summarise(freq=mean(freq),sdabsfft=sd(absfft),absfft=mean(absfft))

## make a plot comparing the WTs to the simulation -- remember this is the full simulation and do indicate
## that in the filename!

# do a quick plot comparing WTs FFTs. in this one WTs are avgd, below they arent. 
myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) + ### use dev_time not realdev_time!!!!
  #geom_line(data=fourier_div_rate_avg_exp, aes(freq,absfft), color = "black", size=0.8) + 
  geom_line(data=fourier_div_rate_avg_exp, aes(freq,absfft), color = "black", size=0.4,alpha=0.75) +
  geom_ribbon(data=fourier_div_rate_avg_exp, aes(freq,ymax=absfft+sdabsfft,ymin=absfft-sdabsfft), size=0.4, alpha = 0.4, fill = "black") +
  #geom_line(data=sim_fourier, aes(freq,absfft), color = "red", size=0.8) +
  geom_line(data=sim_fourier, aes(freq,absfft), size=0.4, alpha = 0.75, colour = "red") +
  geom_ribbon(data=sim_fourier, aes(freq,ymax=absfft+sdabsfft,ymin=absfft-sdabsfft), size=0.4, alpha = 0.4, fill = "red") + 
  scale_color_manual(values=movieColors) +
  scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(0,2.1), breaks=seq(0,2,1), expand = c(0,0), labels = every_nth(seq(0,2,1), 1, inverse = TRUE)) +
  scale_y_continuous(limits=c(0,0.21), breaks=seq(0,0.21,0.05), expand = c(0,0), labels = every_nth(seq(0,0.21,0.05), 2, inverse = TRUE)) +
  #ylim(0,0.25) +
  #xlim(0,2) +
  xlab("Freq (hr-1)")+
  ylab(expression(paste("FT div. rate"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("FULLSIM_absfft_WTs_expavgd_simrunavgd.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)


myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) + ### use dev_time not realdev_time!!!!
  geom_line(data=fourier_div_rate_WT1, aes(freq,absfft,colour=movie), size=0.4) + 
  geom_line(data=fourier_div_rate_WT2, aes(freq,absfft,colour=movie), size=0.4) + 
  geom_line(data=fourier_div_rate_WT3, aes(freq,absfft,colour=movie), size=0.4) + 
  geom_line(data=fourier_div_rate_WT4, aes(freq,absfft,colour=movie), size=0.4) + 
  geom_line(data=sim_fourier, aes(freq,absfft), color = "grey35", size=0.4) +
  scale_color_manual(values=movieColors) +
  scale_fill_manual(values=movieColors) +
  #scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  ylim(0,12.5) +
  xlim(0,2) +
  xlab("Freq (hr-1)")+
  ylab(expression(paste("FT div. rate"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("FULLSIM_absfft_WTs_exp_simrunavgd.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)




## END FOURIER DIV RATE SECTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

### EXTRA STUFF REGARDING SETTING Coeff Variation FOR LIFETIME AS PROPORTION OF MEAN.
WT1_lifetime$CV <- WT1_lifetime$sd_life/WT1_lifetime$mean_life
WT2_lifetime$CV <- WT2_lifetime$sd_life/WT2_lifetime$mean_life
WT3_lifetime$CV <- WT3_lifetime$sd_life/WT3_lifetime$mean_life
WT4_lifetime$CV <- WT4_lifetime$sd_life/WT4_lifetime$mean_life
WT1_mean_CV <- WT1_lifetime %>% summarise(mean_CV = mean(CV))
WT2_mean_CV <- WT2_lifetime %>% summarise(mean_CV = mean(CV))
WT3_mean_CV <- WT3_lifetime %>% summarise(mean_CV = mean(CV))
WT4_mean_CV <- WT3_lifetime %>% summarise(mean_CV = mean(CV))
all_mean_CV <- rbind(WT1_mean_CV,WT2_mean_CV,WT3_mean_CV,WT4_mean_CV)
CV_to_use <- all_mean_CV %>% summarise(CV=mean(mean_CV))




### EXTRA STUFF TO MEASURE THE REALISED SYNTHETIC LIFETIMES IN SIMULATION AND CHECK CV IS AS INPUTTED ETC.
LIFETIMES_ARRAY_TESTWT1 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/LIFETIMES_ARRAY_TESTWT1.csv",header=FALSE, sep= " ") %>% na.omit() 
raw <- LIFETIMES_ARRAY_TESTWT1 %>% rename(birth_time = V1, lifetime = V2, type = V3)
# type 0 only
raw_type0 <- raw %>% filter(type == 0)
library("Hmisc")
myplot <- ggplot(raw_type0,aes(x=birth_time, y=lifetime)) +
  theme(text = element_text(size = 18)) +
  geom_point(alpha=0.3) +
  stat_summary_bin(fun.y='mean',bins=20,geom='point',color='orange',size=2) +
  stat_summary_bin(fun.data = "mean_sdl",fun.args = list(mult = 1), geom = "errorbar",bins=20) +
  xlab(expression(paste("birth time (hr)"))) +
  ylab(expression(paste("lifetime (hr)")))
pdf("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/lifetime_array_binned.pdf")
print(myplot)
dev.off()

## finally, use this to calculate time-averaged value of the CV used for lifetimes.
extra_binsize=2
bin_sim_lifetimes_type0 <- raw_type0 %>% mutate(mid_birth_time = extra_binsize*floor(birth_time / extra_binsize) + (extra_binsize/2)) %>% group_by(mid_birth_time) %>% summarise(mean_lifetime = mean(lifetime), sd_lifetime = sd(lifetime), count = n()) %>% mutate(CV=sd_lifetime/mean_lifetime)
sim_avg_CV <- bin_sim_lifetimes_type0 %>% summarise(avg_CV = mean(CV))








### EXTRA STUFF BASED ON STARTAT16 SIMULATION   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
## possible error before. need to make sure not to use offsetted time in the division rate stuff.


## reload the avgisodefrate data here without trimming. 
## perhaps add the experimental ones in half transparent.
avgIsoDefRateSummary_WT1 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT1$frame <- round(avgIsoDefRateSummary_WT1$dev_time*60/2.5)
avgIsoDefRateSummary_WT1$realframe <- avgIsoDefRateSummary_WT1$frame + offset_WT1
avgIsoDefRateSummary_WT1$realdev_time <- avgIsoDefRateSummary_WT1$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT1$roi <- as.character(avgIsoDefRateSummary_WT1$roi)
avgIsoDefRateSummary_WT1$isoContrib <- as.character(avgIsoDefRateSummary_WT1$isoContrib)
#
avgIsoDefRateSummary_WT2 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT2$frame <- round(avgIsoDefRateSummary_WT2$dev_time*60/2.5)
avgIsoDefRateSummary_WT2$realframe <- avgIsoDefRateSummary_WT2$frame + offset_WT2
avgIsoDefRateSummary_WT2$realdev_time <- avgIsoDefRateSummary_WT2$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT2$roi <- as.character(avgIsoDefRateSummary_WT2$roi)
avgIsoDefRateSummary_WT2$isoContrib <- as.character(avgIsoDefRateSummary_WT2$isoContrib)
#
avgIsoDefRateSummary_WT3 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT3$frame <- round(avgIsoDefRateSummary_WT3$dev_time*60/2.5)
avgIsoDefRateSummary_WT3$realframe <- avgIsoDefRateSummary_WT3$frame + offset_WT3
avgIsoDefRateSummary_WT3$realdev_time <- avgIsoDefRateSummary_WT3$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT3$roi <- as.character(avgIsoDefRateSummary_WT3$roi)
avgIsoDefRateSummary_WT3$isoContrib <- as.character(avgIsoDefRateSummary_WT3$isoContrib)
#
avgIsoDefRateSummary_WT4 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/avgIsoDefRateSummary_ks21.csv") 
avgIsoDefRateSummary_WT4$frame <- round(avgIsoDefRateSummary_WT4$dev_time*60/2.5)
avgIsoDefRateSummary_WT4$realframe <- avgIsoDefRateSummary_WT4$frame + offset_WT4
avgIsoDefRateSummary_WT4$realdev_time <- avgIsoDefRateSummary_WT4$realframe * 2.5/60
# removing factors (?? what does this do?)
avgIsoDefRateSummary_WT4$roi <- as.character(avgIsoDefRateSummary_WT4$roi)
avgIsoDefRateSummary_WT4$isoContrib <- as.character(avgIsoDefRateSummary_WT4$isoContrib)

# frames data to calculate min and max real frame to have
load("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/frames.RData")
frames_WT1 <- frames
load("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/frames.RData")
frames_WT2 <- frames
load("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/frames.RData")
frames_WT3 <- frames
load("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/frames.RData")
frames_WT4 <- frames

## %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Combined RATE contribs for given isoContrib (division here) from different WTs
## IS STILL OFFSET DATA BUT JUST NEED TO MAKE SURE TO USE DEV_TIME NOT REALDEV_TIME BELOW. 
avgIsoDefRateSummary_allWTs_division <- rbind(avgIsoDefRateSummary_WT1 %>% filter(isoContrib=="division") %>% mutate(movie = "WT1"), avgIsoDefRateSummary_WT2 %>% filter(isoContrib=="division") %>% mutate(movie = "WT2"),
                                              avgIsoDefRateSummary_WT3  %>% filter(isoContrib=="division") %>% mutate(movie = "WT3"), avgIsoDefRateSummary_WT4 %>% filter(isoContrib=="division") %>% mutate(movie = "WT4"))




# do for each of WTs separately, not time shifted, and so on. 
WT1_number_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/cellnumber_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT1_number_noborder <- WT1_number_noborder %>% select(frame, n) %>% mutate(movie = "WT1") %>% mutate(dev_time = frame*2.5/60) %>% select(dev_time,n,movie)
WT1_SOP_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/cumul_counts/count_SOP_noborder.csv",header=TRUE) %>% na.omit() %>% mutate
# mutate to offset dev_time
WT1_SOP_noborder <- WT1_SOP_noborder %>% select(frame,count) %>% mutate(n = count,dev_time=frame*2.5/60) %>% select(dev_time,n) %>% mutate(movie = "WT1")

WT1_dropout_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/count_dropout_noborder.csv",header=TRUE) %>% na.omit() %>% select(-X)
#pad from 0 to start.
pad <- data.frame(seq(0,149))
colnames(pad) <- "frame"
pad$dev_time <- pad$frame*2.5/60
pad$count <- 0
WT1_dropout_noborder <- WT1_dropout_noborder %>% rbind(pad) %>% arrange(frame)
# mutate to offset dev_time
WT1_dropout_noborder <- WT1_dropout_noborder %>% select(frame,count) %>% mutate(n = count,dev_time=frame*2.5/60) %>% select(dev_time,n) %>% mutate(movie = "WT1")

WT1_number_noborder$series = "noborder"
WT1_SOP_noborder$series = "SOP"
WT1_dropout_noborder$series = "quiescent"
WT1_celltypes_number <- rbind(WT1_number_noborder,WT1_SOP_noborder,WT1_dropout_noborder)

# simulation specific to WT1
## looking good. now want to get in the simulation numbers. 
sim_number_noborderWT1 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_all_types_no_borderWT1.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_number_noborderWT1) <- c("dev_time", "n")
sim_number_noborderWT1$series <- "noborder"

sim_quiescent_noborderWT1 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_quiescent_cells_no_borderWT1.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_quiescent_noborderWT1) <- c("dev_time", "n")
sim_quiescent_noborderWT1$series <- "quiescent"

sim_SOP_noborderWT1 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_SOPs_no_borderWT1.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_SOP_noborderWT1) <- c("dev_time", "n")
sim_SOP_noborderWT1$series <- "SOP"



## WT1 CD division rate startat16h comparison
sim_div_rate_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/kd_array_no_border_smoothedWT1.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_div_rate_noborder ) <- c("dev_time", "rate")







## WT2
WT2_number_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/cellnumber_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT2_number_noborder <- WT2_number_noborder %>% select(frame, n) %>% mutate(movie = "WT2") %>% mutate(dev_time = frame*2.5/60) %>% select(dev_time,n,movie)
WT2_SOP_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/cumul_counts/count_SOP_noborder.csv",header=TRUE) %>% na.omit() %>% mutate
# mutate to offset dev_time
WT2_SOP_noborder <- WT2_SOP_noborder %>% select(frame,count) %>% mutate(n = count,dev_time=frame*2.5/60) %>% select(dev_time,n) %>% mutate(movie = "WT2")

WT2_dropout_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/count_dropout_noborder.csv",header=TRUE) %>% na.omit() %>% select(-X)
#pad from 0 to start.
pad <- data.frame(seq(0,149))
colnames(pad) <- "frame"
pad$dev_time <- pad$frame*2.5/60
pad$count <- 0
WT2_dropout_noborder <- WT2_dropout_noborder %>% rbind(pad) %>% arrange(frame)
# mutate to offset dev_time
WT2_dropout_noborder <- WT2_dropout_noborder %>% select(frame,count) %>% mutate(n = count,dev_time=frame*2.5/60) %>% select(dev_time,n) %>% mutate(movie = "WT2")

WT2_number_noborder$series = "noborder"
WT2_SOP_noborder$series = "SOP"
WT2_dropout_noborder$series = "quiescent"
WT2_celltypes_number <- rbind(WT2_number_noborder,WT2_SOP_noborder,WT2_dropout_noborder)

# simulation specific to WT2
## looking good. now want to get in the simulation numbers. 
sim_number_noborderWT2 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_all_types_no_borderWT2.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_number_noborderWT2) <- c("dev_time", "n")
sim_number_noborderWT2$series <- "noborder"

sim_quiescent_noborderWT2 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_quiescent_cells_no_borderWT2.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_quiescent_noborderWT2) <- c("dev_time", "n")
sim_quiescent_noborderWT2$series <- "quiescent"

sim_SOP_noborderWT2 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_SOPs_no_borderWT2.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_SOP_noborderWT2) <- c("dev_time", "n")
sim_SOP_noborderWT2$series <- "SOP"


## WT2 CD division rate startat16h comparison
sim_div_rate_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/kd_array_no_border_smoothedWT2.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_div_rate_noborder ) <- c("dev_time", "rate")



## WT3
WT3_number_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/cellnumber_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT3_number_noborder <- WT3_number_noborder %>% select(frame, n) %>% mutate(movie = "WT3") %>% mutate(dev_time = frame*2.5/60) %>% select(dev_time,n,movie)
WT3_SOP_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/cumul_counts/count_SOP_noborder.csv",header=TRUE) %>% na.omit() %>% mutate
# mutate to offset dev_time
WT3_SOP_noborder <- WT3_SOP_noborder %>% select(frame,count) %>% mutate(n = count,dev_time=frame*2.5/60) %>% select(dev_time,n) %>% mutate(movie = "WT3")

WT3_dropout_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/count_dropout_noborder.csv",header=TRUE) %>% na.omit() %>% select(-X)
#pad from 0 to start.
pad <- data.frame(seq(0,149))
colnames(pad) <- "frame"
pad$dev_time <- pad$frame*2.5/60
pad$count <- 0
WT3_dropout_noborder <- WT3_dropout_noborder %>% rbind(pad) %>% arrange(frame)
# mutate to offset dev_time
WT3_dropout_noborder <- WT3_dropout_noborder %>% select(frame,count) %>% mutate(n = count,dev_time=frame*2.5/60) %>% select(dev_time,n) %>% mutate(movie = "WT3")

WT3_number_noborder$series = "noborder"
WT3_SOP_noborder$series = "SOP"
WT3_dropout_noborder$series = "quiescent"
WT3_celltypes_number <- rbind(WT3_number_noborder,WT3_SOP_noborder,WT3_dropout_noborder)

# simulation specific to WT3
## looking good. now want to get in the simulation numbers. 
sim_number_noborderWT3 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_all_types_no_borderWT3.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_number_noborderWT3) <- c("dev_time", "n")
sim_number_noborderWT3$series <- "noborder"

sim_quiescent_noborderWT3 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_quiescent_cells_no_borderWT3.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_quiescent_noborderWT3) <- c("dev_time", "n")
sim_quiescent_noborderWT3$series <- "quiescent"

sim_SOP_noborderWT3 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_SOPs_no_borderWT3.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_SOP_noborderWT3) <- c("dev_time", "n")
sim_SOP_noborderWT3$series <- "SOP"


## WT3 CD division rate startat16h comparison
sim_div_rate_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/kd_array_no_border_smoothedWT3.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_div_rate_noborder ) <- c("dev_time", "rate")


## WT4
WT4_number_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/cellnumber_noborder.csv",header=TRUE) %>% na.omit()
# mutate to offset dev_time
WT4_number_noborder <- WT4_number_noborder %>% select(frame, n) %>% mutate(movie = "WT4") %>% mutate(dev_time = frame*2.5/60) %>% select(dev_time,n,movie)
WT4_SOP_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/cumul_counts/count_SOP_noborder.csv",header=TRUE) %>% na.omit() %>% mutate
# mutate to offset dev_time
WT4_SOP_noborder <- WT4_SOP_noborder %>% select(frame,count) %>% mutate(n = count,dev_time=frame*2.5/60) %>% select(dev_time,n) %>% mutate(movie = "WT4")

WT4_dropout_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/count_dropout_noborder.csv",header=TRUE) %>% na.omit() %>% select(-X)
#pad from 0 to start.
pad <- data.frame(seq(0,149))
colnames(pad) <- "frame"
pad$dev_time <- pad$frame*2.5/60
pad$count <- 0
WT4_dropout_noborder <- WT4_dropout_noborder %>% rbind(pad) %>% arrange(frame)
# mutate to offset dev_time
WT4_dropout_noborder <- WT4_dropout_noborder %>% select(frame,count) %>% mutate(n = count,dev_time=frame*2.5/60) %>% select(dev_time,n) %>% mutate(movie = "WT4")

WT4_number_noborder$series = "noborder"
WT4_SOP_noborder$series = "SOP"
WT4_dropout_noborder$series = "quiescent"
WT4_celltypes_number <- rbind(WT4_number_noborder,WT4_SOP_noborder,WT4_dropout_noborder)

# simulation specific to WT4
## looking good. now want to get in the simulation numbers. 
sim_number_noborderWT4 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_all_types_no_borderWT4.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_number_noborderWT4) <- c("dev_time", "n")
sim_number_noborderWT4$series <- "noborder"

sim_quiescent_noborderWT4 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_quiescent_cells_no_borderWT4.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_quiescent_noborderWT4) <- c("dev_time", "n")
sim_quiescent_noborderWT4$series <- "quiescent"

sim_SOP_noborderWT4 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/nb_cells_SOPs_no_borderWT4.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_SOP_noborderWT4) <- c("dev_time", "n")
sim_SOP_noborderWT4$series <- "SOP"



## WT4 CD division rate startat16h comparison
sim_div_rate_noborder <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/John_Williamson/startat16_jjw_GS_Sim_Population_Growth_Python/results_basecase5aug/kd_array_no_border_smoothedWT4.csv",header=FALSE, sep= " ") %>% na.omit() 
colnames(sim_div_rate_noborder ) <- c("dev_time", "rate")



### Measuring p and alpha directly in the startat16h simulation. see if it is what we put in.
## measure with a variable for the bin size. copy measurement code from consolidate_noborder etc.
## the bin size there was 25 frames.
## type 0 is dividing
## type 1 is red cell
## type 2 is SOP

## WT1 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
binsize <- 1.0416666667 #(25 frames in hours)
sim_divisions_WT1 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from16hAPF/results_WT1/LIFETIMES_ARRAY_run_0.csv",header=FALSE, sep= " ") %>% na.omit() 
sim_divisions_WT1 <- sim_divisions_WT1 %>% rename(dev_time = V1,left_lifetime = V2, left_type = V3, right_lifetime = V4, right_type = V5)
sim_divisions_WT1 <- sim_divisions_WT1 %>% mutate(mid_time = binsize*floor(dev_time / binsize) + 0.5*binsize)
sim_divisions_WT1$dummy <- 1 # dummy for counting in groups
# do we exclude divisions that make SOPs? no we didn't in consolidate_noborder so don't do it here. mnust do the same calculation
palpha_sim_measured_WT1 <- sim_divisions_WT1 %>% group_by(mid_time) %>% summarise(n_div = sum(dummy), n_0red = sum(dummy[left_type != 1 & right_type != 1]), n_1red = sum(dummy[(left_type == 1 & right_type != 1) | (left_type != 1 & right_type == 1) ]) , n_2red = sum(dummy[(left_type == 1 & right_type == 1)]))
# for interest find the number of divisions not included in n0red, n1red or n2red. should be zero because SOPs are also accounted for as 'not red'. this is as measured in experiments.
palpha_sim_measured_WT1 <- palpha_sim_measured_WT1 %>% mutate(discrep = n_div - n_0red - n_1red - n_2red)
# then measure p and alpha
palpha_sim_measured_WT1 <- palpha_sim_measured_WT1 %>% mutate(p = 1 - (n_0red/n_div)) %>% mutate(alpha = n_2red/(n_div*p))

# P plot, can also compare to the fitted input and to the experiment WT1
switchtime_p <- 26.4
hillcoeff_p <- 42

pandalpha_exp_WT1 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT1/core/noborder/pandalpha.csv") 

myplot <- ggplot(palpha_sim_measured_WT1, aes(mid_time, p)) +
  geom_line(size=0.6) +
  geom_line(data = pandalpha_exp_WT1, aes(dev_time+16,p),size=0.6, colour = "blue") +
  geom_point(size=0.8) + 
  stat_function(fun = function(.x)  1*(.x/switchtime_p)^hillcoeff_p / ((.x/switchtime_p)^(hillcoeff_p) + 1) , colour = "red", size = 0.8   ) +
  #geom_errorbar(aes(ymin=(p-std), ymax=(p+std)),
         #       size=0.8, width=0.425) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  xlab("Time (hAPF)  ")+
  ylab(expression(paste("p"))) +
  #scale_color_manual(values=movieColors) +
  #scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,33), breaks=c(16,18.5,21,23.5,26,28.5,31), expand = c(0,0), labels = every_nth(c(16,18.5,21,23.5,26,28.5,31), 2, inverse = TRUE)) +
  scale_y_continuous(limits=c(-0.1,1.1), expand = c(0,0))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("p_sim_comparison_WT1.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## WT 2 P comparison%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5
## WT2 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
binsize <- 1.0416666667 #(25 frames in hours)
sim_divisions_WT2 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from16hAPF/results_WT2/LIFETIMES_ARRAY_run_0.csv",header=FALSE, sep= " ") %>% na.omit() 
sim_divisions_WT2 <- sim_divisions_WT2 %>% rename(dev_time = V1,left_lifetime = V2, left_type = V3, right_lifetime = V4, right_type = V5)
sim_divisions_WT2 <- sim_divisions_WT2 %>% mutate(mid_time = binsize*floor(dev_time / binsize) + 0.5*binsize)
sim_divisions_WT2$dummy <- 1 # dummy for counting in groups
# do we exclude divisions that make SOPs? no we didn't in consolidate_noborder so don't do it here. mnust do the same calculation
palpha_sim_measured_WT2 <- sim_divisions_WT2 %>% group_by(mid_time) %>% summarise(n_div = sum(dummy), n_0red = sum(dummy[left_type != 1 & right_type != 1]), n_1red = sum(dummy[(left_type == 1 & right_type != 1) | (left_type != 1 & right_type == 1) ]) , n_2red = sum(dummy[(left_type == 1 & right_type == 1)]))
# for interest find the number of divisions not included in n0red, n1red or n2red. should be zero because SOPs are also accounted for as 'not red'. this is as measured in experiments.
palpha_sim_measured_WT2 <- palpha_sim_measured_WT2 %>% mutate(discrep = n_div - n_0red - n_1red - n_2red)
# then measure p and alpha
palpha_sim_measured_WT2 <- palpha_sim_measured_WT2 %>% mutate(p = 1 - (n_0red/n_div)) %>% mutate(alpha = n_2red/(n_div*p))

# P plot, can also compare to the fitted input and to the experiment WT2
switchtime_p <- 27.8
hillcoeff_p <- 32

pandalpha_exp_WT2 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT2/core/noborder/pandalpha.csv") 

myplot <- ggplot(palpha_sim_measured_WT2, aes(mid_time, p)) +
  geom_line(size=0.6) +
  geom_line(data = pandalpha_exp_WT2, aes(dev_time+16,p),size=0.6, colour = "blue") +
  geom_point(size=0.8) + 
  stat_function(fun = function(.x)  1*(.x/switchtime_p)^hillcoeff_p / ((.x/switchtime_p)^(hillcoeff_p) + 1) , colour = "red", size = 0.8   ) +
  #geom_errorbar(aes(ymin=(p-std), ymax=(p+std)),
  #       size=0.8, width=0.425) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  xlab("Time (hAPF)  ")+
  ylab(expression(paste("p"))) +
  #scale_color_manual(values=movieColors) +
  #scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,33), breaks=c(16,18.5,21,23.5,26,28.5,31), expand = c(0,0), labels = every_nth(c(16,18.5,21,23.5,26,28.5,31), 2, inverse = TRUE)) +
  scale_y_continuous(limits=c(-0.1,1.1), expand = c(0,0))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("p_sim_comparison_WT2.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## WT3 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
binsize <- 1.0416666667 #(25 frames in hours)
sim_divisions_WT3 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from16hAPF/results_WT3/LIFETIMES_ARRAY_run_0.csv",header=FALSE, sep= " ") %>% na.omit() 
sim_divisions_WT3 <- sim_divisions_WT3 %>% rename(dev_time = V1,left_lifetime = V2, left_type = V3, right_lifetime = V4, right_type = V5)
sim_divisions_WT3 <- sim_divisions_WT3 %>% mutate(mid_time = binsize*floor(dev_time / binsize) + 0.5*binsize)
sim_divisions_WT3$dummy <- 1 # dummy for counting in groups
# do we exclude divisions that make SOPs? no we didn't in consolidate_noborder so don't do it here. mnust do the same calculation
palpha_sim_measured_WT3 <- sim_divisions_WT3 %>% group_by(mid_time) %>% summarise(n_div = sum(dummy), n_0red = sum(dummy[left_type != 1 & right_type != 1]), n_1red = sum(dummy[(left_type == 1 & right_type != 1) | (left_type != 1 & right_type == 1) ]) , n_2red = sum(dummy[(left_type == 1 & right_type == 1)]))
# for interest find the number of divisions not included in n0red, n1red or n2red. should be zero because SOPs are also accounted for as 'not red'. this is as measured in experiments.
palpha_sim_measured_WT3 <- palpha_sim_measured_WT3 %>% mutate(discrep = n_div - n_0red - n_1red - n_2red)
# then measure p and alpha
palpha_sim_measured_WT3 <- palpha_sim_measured_WT3 %>% mutate(p = 1 - (n_0red/n_div)) %>% mutate(alpha = n_2red/(n_div*p))

# P plot, can also compare to the fitted input and to the experiment WT3
switchtime_p <- 26
hillcoeff_p <- 40

pandalpha_exp_WT3 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT3/core/noborder/pandalpha.csv") 

myplot <- ggplot(palpha_sim_measured_WT3, aes(mid_time, p)) +
  geom_line(size=0.6) +
  geom_line(data = pandalpha_exp_WT3, aes(dev_time+16,p),size=0.6, colour = "blue") +
  geom_point(size=0.8) + 
  stat_function(fun = function(.x)  1*(.x/switchtime_p)^hillcoeff_p / ((.x/switchtime_p)^(hillcoeff_p) + 1) , colour = "red", size = 0.8   ) +
  #geom_errorbar(aes(ymin=(p-std), ymax=(p+std)),
  #       size=0.8, width=0.425) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  xlab("Time (hAPF)  ")+
  ylab(expression(paste("p"))) +
  #scale_color_manual(values=movieColors) +
  #scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,33), breaks=c(16,18.5,21,23.5,26,28.5,31), expand = c(0,0), labels = every_nth(c(16,18.5,21,23.5,26,28.5,31), 2, inverse = TRUE)) +
  scale_y_continuous(limits=c(-0.1,1.1), expand = c(0,0))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("p_sim_comparison_WT3.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## WT4 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
binsize <- 1.0416666667 #(25 frames in hours)
sim_divisions_WT4 <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from16hAPF/results_WT4/LIFETIMES_ARRAY_run_0.csv",header=FALSE, sep= " ") %>% na.omit() 
sim_divisions_WT4 <- sim_divisions_WT4 %>% rename(dev_time = V1,left_lifetime = V2, left_type = V3, right_lifetime = V4, right_type = V5)
sim_divisions_WT4 <- sim_divisions_WT4 %>% mutate(mid_time = binsize*floor(dev_time / binsize) + 0.5*binsize)
sim_divisions_WT4$dummy <- 1 # dummy for counting in groups
# do we exclude divisions that make SOPs? no we didn't in consolidate_noborder so don't do it here. mnust do the same calculation
palpha_sim_measured_WT4 <- sim_divisions_WT4 %>% group_by(mid_time) %>% summarise(n_div = sum(dummy), n_0red = sum(dummy[left_type != 1 & right_type != 1]), n_1red = sum(dummy[(left_type == 1 & right_type != 1) | (left_type != 1 & right_type == 1) ]) , n_2red = sum(dummy[(left_type == 1 & right_type == 1)]))
# for interest find the number of divisions not included in n0red, n1red or n2red. should be zero because SOPs are also accounted for as 'not red'. this is as measured in experiments.
palpha_sim_measured_WT4 <- palpha_sim_measured_WT4 %>% mutate(discrep = n_div - n_0red - n_1red - n_2red)
# then measure p and alpha
palpha_sim_measured_WT4 <- palpha_sim_measured_WT4 %>% mutate(p = 1 - (n_0red/n_div)) %>% mutate(alpha = n_2red/(n_div*p))

# P plot, can also compare to the fitted input and to the experiment WT4
switchtime_p <- 25.4
hillcoeff_p <- 46

pandalpha_exp_WT4 <- read.csv(file="/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/CSVs_movies_plots/WT4/core/noborder/pandalpha.csv") 

myplot <- ggplot(palpha_sim_measured_WT4, aes(mid_time, p)) +
  geom_line(size=0.6) +
  geom_line(data = pandalpha_exp_WT4, aes(dev_time+16,p),size=0.6, colour = "blue") +
  geom_point(size=0.8) + 
  stat_function(fun = function(.x)  1*(.x/switchtime_p)^hillcoeff_p / ((.x/switchtime_p)^(hillcoeff_p) + 1) , colour = "red", size = 0.8   ) +
  #geom_errorbar(aes(ymin=(p-std), ymax=(p+std)),
  #       size=0.8, width=0.425) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  xlab("Time (hAPF)  ")+
  ylab(expression(paste("p"))) +
  #scale_color_manual(values=movieColors) +
  #scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,33), breaks=c(16,18.5,21,23.5,26,28.5,31), expand = c(0,0), labels = every_nth(c(16,18.5,21,23.5,26,28.5,31), 2, inverse = TRUE)) +
  scale_y_continuous(limits=c(-0.1,1.1), expand = c(0,0))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("p_sim_comparison_WT4.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)




## ESTIMATING FULL ANTERIOR SIZE FROM SIMULATION EXTRAPOLATION 

for (i in seq(0,N_RUNS-1)) {
  # FULL ANTERIOR number
  filename = gsub(" \\d ", paste(i), paste("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/nb_cells_second_phase_total_all_types_run_",i,".csv",sep=""))
  temp <- read.csv(filename,header=FALSE, sep= " ") %>% na.omit() 
  colnames(temp) <- c("dev_time", "n")
  temp$series <- "anterior"
  temp$run <- i
  if (i == 0)  {
    sim_statistical_fullanterior <- temp
  } else {
    sim_statistical_fullanterior <- rbind(sim_statistical_fullanterior,temp)  
  }
  
}

sim_statistical_fullanterior <- sim_statistical_fullanterior %>% group_by(dev_time,series) %>% summarise(mean = mean(n),sd = sd(n)) %>% ungroup()

sim_statistical_fullanterior <- sim_statistical_fullanterior %>% rbind(sim_pre16h_statistical)
sim_statistical_fullanterior$series <- "anterior"
## plot 
myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_ribbon(data=sim_statistical_fullanterior,aes(dev_time,ymin=(mean-sd), ymax=(mean+sd), fill = series,color=series),size=0.25, alpha=0.5) + 
  geom_line(data=sim_statistical_fullanterior, aes(dev_time,mean,color=series), size=0.5) + 
  scale_color_manual(values=c("anterior" = "darkgreen")) +
  scale_fill_manual(values=c("anterior" = "darkgreen")) +
  xlab("Time (hAPF)")+
  scale_x_continuous(limits=c(16,40), breaks=seq(16,40,2.5), expand = c(0,0), labels = every_nth(seq(16,40,2.5), 2, inverse = TRUE)) +
  ylab(expression(paste("Cell number fullanterior (sim.)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("STATISTICAL_celltypes_number_fullanterior.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)


## Work out the average number of divisions for anterior nest cells based on an N0 given by the experimental earlystage data at 14hAPF.
## Need to propagate errors properly I guess. 14hAPF value is 188 cells +- 24. 
## https://stats.stackexchange.com/questions/324957/propagation-of-error-in-log-ratios
fullanteriorN0 <- graphdata2 %>% filter(dev_time == 14) %>% select(-dev_time)
fullanterior_normd_errorspropagated <- sim_statistical_fullanterior
fullanterior_normd_errorspropagated$N0 <- fullanteriorN0$y
fullanterior_normd_errorspropagated$N0_err <- fullanteriorN0$err_y

fullanterior_normd_errorspropagated$normd <- fullanterior_normd_errorspropagated$mean / fullanterior_normd_errorspropagated$N0
fullanterior_normd_errorspropagated$log2normd <- log2(fullanterior_normd_errorspropagated$normd)

fullanterior_normd_errorspropagated <- fullanterior_normd_errorspropagated %>% mutate(log2normd_err = (N0_err/(N0*log(2)) + (sd/(mean*log(2))   ) ))
fullanterior_normd_errorspropagated$series <- "anterior"

#plot
myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_ribbon(data=fullanterior_normd_errorspropagated,aes(dev_time,ymin=(log2normd-log2normd_err), ymax=(log2normd+log2normd_err), fill = series,color=series),size=0.25, alpha=0.5) + 
  geom_line(data=fullanterior_normd_errorspropagated, aes(dev_time,log2normd,color=series), size=0.5) + 
  scale_color_manual(values=c("anterior" = "darkgreen")) +
  scale_fill_manual(values=c("anterior" = "darkgreen")) +
  xlab("Time (hAPF)")+
  scale_x_continuous(limits=c(16,40), breaks=seq(16,40,2.5), expand = c(0,0), labels = every_nth(seq(16,40,2.5), 2, inverse = TRUE)) +
  ylab(expression(paste("Log2 N/N0 fullanterior"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("STATISTICAL_log2NoverN0_fullanterior.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

## make this plot go further back (need to add more data too).

myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  geom_ribbon(data=fullanterior_normd_errorspropagated,aes(dev_time,ymin=(log2normd-log2normd_err), ymax=(log2normd+log2normd_err), fill = series,color=series),size=0.25, alpha=0.5) + 
  geom_line(data=fullanterior_normd_errorspropagated, aes(dev_time,log2normd,color=series), size=0.5) + 
  scale_color_manual(values=c("anterior" = "darkgreen")) +
  scale_fill_manual(values=c("anterior" = "darkgreen")) +
  xlab("Time (hAPF)")+
  scale_x_continuous(limits=c(12,40), breaks=seq(12,40,2), expand = c(0,0), labels = every_nth(seq(12,40,2), 2, inverse = TRUE)) +
  ylab(expression(paste("Log2 N/N0 fullanterior"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("STATISTICAL_log2NoverN0_fullanterior_furtherback.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)



## FURTHER ERROR PROPAGATION ON EG THE AVG NUMBER OF CLEAVAGE DIVISIONS. 0hAPF is 18 +- 1.71
#https://stats.stackexchange.com/questions/324957/propagation-of-error-in-log-ratios
log2_graphdata2_errorspropagated <- graphdata2
log2_graphdata2_errorspropagated <- log2_graphdata2_errorspropagated %>% mutate(log2data = log2(y/18)) %>% mutate(log2error = (err_y / (y*log(2))) + (1.71 / (18*log(2))) )
log2_graphdata2_errorspropagated <- log2_graphdata2_errorspropagated %>% mutate(log2errorratio = log2error / log2data) %>% mutate(cycletimedata = dev_time/log2data) %>% mutate(cycletimeerror = log2errorratio*cycletimedata)






## NEW 4 AUG %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
## FOR FULL BASE CASE SIM. measure the realised p and alpha in the sim
## just using run 0 here for testing

binsize <- 1.0416666667 #(25 frames in hours)
sim_divisions_fullsim <- read.csv("/Users/john/Dropbox (The Francis Crick)/CRICK/FIRST_HISTOBLAST_PAPER/Simulations_Final/Simulation_from0hAPF/results_shorter_pause/LIFETIMES_ARRAY_run_0.csv",header=FALSE, sep= " ") %>% na.omit() 
sim_divisions_fullsim <- sim_divisions_fullsim %>% rename(dev_time = V1,left_lifetime = V2, left_type = V3, right_lifetime = V4, right_type = V5)
sim_divisions_fullsim <- sim_divisions_fullsim %>% mutate(mid_time = binsize*floor(dev_time / binsize) + 0.5*binsize)
sim_divisions_fullsim$dummy <- 1 # dummy for counting in groups
# do we exclude divisions that make SOPs? no we didn't in consolidate_noborder so don't do it here. mnust do the same calculation
palpha_sim_measured_fullsim <- sim_divisions_fullsim %>% group_by(mid_time) %>% summarise(n_div = sum(dummy), n_0red = sum(dummy[left_type != 1 & right_type != 1]), n_1red = sum(dummy[(left_type == 1 & right_type != 1) | (left_type != 1 & right_type == 1) ]) , n_2red = sum(dummy[(left_type == 1 & right_type == 1)]))
# for interest find the number of divisions not included in n0red, n1red or n2red. should be zero because SOPs are also accounted for as 'not red'. this is as measured in experiments.
palpha_sim_measured_fullsim <- palpha_sim_measured_fullsim %>% mutate(discrep = n_div - n_0red - n_1red - n_2red)
# then measure p and alpha
palpha_sim_measured_fullsim <- palpha_sim_measured_fullsim %>% mutate(p = 1 - (n_0red/n_div)) %>% mutate(alpha = n_2red/(n_div*p))

## just compare the fullsim p curve to that inputted
switchtime_p <- 25.7
hillcoeff_p <- 34

myplot <- ggplot(palpha_sim_measured_fullsim, aes(mid_time, p)) +
  geom_line(size=0.6) +
  geom_point(size=0.8) + 
  stat_function(fun = function(.x)  1*(.x/switchtime_p)^hillcoeff_p / ((.x/switchtime_p)^(hillcoeff_p) + 1) , colour = "red", size = 0.8   ) +
  #geom_errorbar(aes(ymin=(p-std), ymax=(p+std)),
  #       size=0.8, width=0.425) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  xlab("Time (hAPF)  ")+
  ylab(expression(paste("p"))) +
  #scale_color_manual(values=movieColors) +
  #scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,33), breaks=c(16,18.5,21,23.5,26,28.5,31), expand = c(0,0), labels = every_nth(c(16,18.5,21,23.5,26,28.5,31), 2, inverse = TRUE)) +
  scale_y_continuous(limits=c(-0.1,1.1), expand = c(0,0))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("p_fullsim_comparison_to_input.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)
##
switchtime_alpha <- 24.7
hillcoeff_alpha <- 34

myplot <- ggplot(palpha_sim_measured_fullsim, aes(mid_time, alpha)) +
  geom_line(size=0.6) +
  geom_point(size=0.8) + 
  stat_function(fun = function(.x)  1*(.x/switchtime_alpha)^hillcoeff_alpha / ((.x/switchtime_alpha)^(hillcoeff_alpha) + 1) , colour = "red", size = 0.8   ) +
  #geom_errorbar(aes(ymin=(p-std), ymax=(p+std)),
  #       size=0.8, width=0.425) +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  xlab("Time (hAPF)  ")+
  ylab(expression(paste("alpha"))) +
  #scale_color_manual(values=movieColors) +
  #scale_fill_manual(values=movieColors) +
  scale_x_continuous(limits=c(16,33), breaks=c(16,18.5,21,23.5,26,28.5,31), expand = c(0,0), labels = every_nth(c(16,18.5,21,23.5,26,28.5,31), 2, inverse = TRUE)) +
  scale_y_continuous(limits=c(-0.1,1.1), expand = c(0,0))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("alpha_fullsim_comparison_to_input.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)