## Lifetime movies (showing full anterior and posterior) for each of WT1 WT2 WT3 WT4.
## keep a common colour scale for all four. Just run this on each movie separately then take snapshots from each and put in the folder.

load("time/roi_bt/lgRoiSmoothed.RData")
load("time/roi_bt/roiCellsBT.RData")
roiAnterior <- roiCellsBT %>% filter(roi == "anterior")
roiPosterior <- roiCellsBT %>% filter(roi == "posterior")
roiBothNests <- rbind(roiAnterior,roiPosterior)

lifetimes_bothnests <- cellinfoDB %>% dt.merge(roiBothNests,by="cell_id") %>% filter(appears_by == "Division" & disappears_by == "Division") %>% select(cell_id,first_occ,last_occ,roi) %>% mutate(lifetime = last_occ-first_occ) %>% select(cell_id,lifetime,roi)

cellshapes_bothnests_lifetime <- cellshapes %>% dt.merge(lifetimes_bothnests,by="cell_id")

render_movie(cellshapes_bothnests_lifetime, "cellshapes_bothnests_lifetime_FigS2.mp4", list(
  geom_polygon(aes(x_pos, y_pos, group=cell_id, fill=lifetime*2.5/60)),
  scale_fill_gradientn(name="Lifetime (h)",
                       colors  = jet.colors(7),
                       # ignore tails of distribution
                       limits=c(1,10),
                       na.value = "black")
))


## HISTOGRAM/DENSITY PLOT. SEPARATE FOR POSTERIOR AND ANTERIOR (COLOURED LIKE THE ROI SNAPSHOTS, SO RED POSTERIOR GREEN ANTERIOR)
## ONE GRAPH FOR EACH MOVIE, WITH COMMON X AXIS.
## quarter hour bin width 

myplot <- ggplot(data=lifetimes_bothnests,aes(lifetime*2.5/60,fill=roi)) +
  geom_histogram(binwidth = 0.25,color="black",size=0.4) +
  scale_x_continuous(limits=c(0,12), breaks=seq(0,12,2), expand = c(0,0), labels = every_nth(seq(0,12,2), 2, inverse = TRUE)) +
  scale_y_continuous(limits=c(0,NA), expand = c(0,0)) + 
  theme(legend.direction="horizontal",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  xlab("Lifetime (h)") +
  ylab("Histogram count") +
  scale_fill_manual(values=c("anterior"="green", "posterior"="red"))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("anterior_posterior_lifetime_histogram.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.55, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)

    