## GS requested cumulative counts of SOPs and of apoptoses (in which tissue? do noborder and full anterior)

dir.create("cumul_counts")

load("time/roi_bt/lgRoiSmoothed.RData")
load("time/roi_bt/roiCellsBT.RData")
roiBothNests <- roiCellsBT %>% filter(roi == "anterior" | roi == "posterior")
roiHistoNoborder <- lgRoiSmoothed %>% filter(roi == "anterior")
roiAnterior <- roiCellsBT %>% filter(roi == "anterior")

## load SOP list
load("time/roi_BT/SOP_cell_id.RData")


## count divisions in noborder
disappearsbydiv_noborder <- cellinfoDB %>% filter(disappears_by == "Division") %>% filter(cell_id %in% roiHistoNoborder$cell_id) %>% select(cell_id,last_occ)
count_div_noborder <- frames %>% select(frame)
# cross join to get every combination of frame and dropout times
count_div_noborder <- merge(x = count_div_noborder, y = disappearsbydiv_noborder, by = NULL)
# then filter
count_div_noborder <- count_div_noborder %>% filter(last_occ < frame)
count_div_noborder <- count_div_noborder %>% select(frame) %>% group_by(frame) %>% summarise(count = n())
count_div_noborder$dev_time <- count_div_noborder$frame*2.5/60
count_div_noborder <- count_div_noborder %>% select(frame,dev_time,count)
# write
write.csv(count_div_noborder,file="cumul_counts/count_div_noborder.csv")

## ADD IN INSERT: MAKE MOVIE SHOWING ALL DIVISIONS (flag cells that disappear by division, in their final frame)
cellshapes_flagdivisions <- cellinfoDB %>% select(cell_id,disappears_by,last_occ) %>% dt.merge(cellshapes,by="cell_id") %>% mutate(flag = (disappears_by == "Division" & frame == last_occ))
render_movie(cellshapes_flagdivisions, "cumul_counts/cellshapes_flagdivisions.mp4", list( 
  # geometrical layer to represent cells as polygons
  geom_polygon(aes(x_pos, y_pos, group=cell_id, alpha = flag), fill = "blue"), # this was 0.75 before, trying this for overlaying multiple with transparency. see evernote. 
  scale_alpha_discrete(range = c(0,0.75))
))



## count apoptoses in noborder
disappearsbyapop_noborder <- cellinfoDB %>% filter(disappears_by == "Apoptosis") %>% filter(cell_id %in% roiHistoNoborder$cell_id) %>% select(cell_id,last_occ)
count_apop_noborder <- frames %>% select(frame)
# cross join to get every combination of frame and  times
count_apop_noborder <- merge(x = count_apop_noborder, y = disappearsbyapop_noborder, by = NULL)
# then filter
count_apop_noborder <- count_apop_noborder %>% filter(last_occ < frame)
count_apop_noborder <- count_apop_noborder %>% select(frame) %>% group_by(frame) %>% summarise(count = n())
count_apop_noborder$dev_time <- count_apop_noborder$frame*2.5/60
count_apop_noborder <- count_apop_noborder %>% select(frame,dev_time,count)
# write 
write.csv(count_apop_noborder,file="cumul_counts/count_apop_noborder.csv")

## count SOPS in noborder
SOPs_noborder <- cellinfoDB %>% filter(cell_id %in% SOP_cell_id$cell_id) %>% filter(cell_id %in% roiHistoNoborder$cell_id) %>% select(cell_id,first_occ)
count_SOP_noborder <- frames %>% select(frame)
# cross join to get every combination of frame and  times
count_SOP_noborder <- merge(x = count_SOP_noborder, y = SOPs_noborder, by = NULL)
# then filter
count_SOP_noborder <- count_SOP_noborder %>% filter(first_occ < frame)
count_SOP_noborder <- count_SOP_noborder %>% select(frame) %>% group_by(frame) %>% summarise(count = n())
count_SOP_noborder$dev_time <- count_SOP_noborder$frame*2.5/60
count_SOP_noborder <- count_SOP_noborder %>% select(frame,dev_time,count)
# pad with zero until thingy first one
firstSOP <- min(count_SOP_noborder$frame)
pad <- frames %>% filter(frame < firstSOP) %>% select(frame)
pad$dev_time <- pad$frame * 2.5/60
pad$count <- 0 
count_SOP_noborder <- rbind(pad,count_SOP_noborder)
# write 
write.csv(count_SOP_noborder,file="cumul_counts/count_SOP_noborder.csv")

## ADDITION! sigmoid fitting to number of SOPs. handle manually I guess. 
#hill function example stuff 0.01+0.99*(time/SwitchTime).^HillCoeff./((time/SwitchTime).^HillCoeff+1)
switchtime <- 5.8
hillcoeff <- 6.8
totalSOPs <- 53
myplot <- ggplot(count_SOP_noborder, aes(dev_time, count)) + 
  geom_line(size = 2)+
  theme(text = element_text(size = 18)) +
  ylab(expression(paste("count"))) + 
  ggtitle(paste("switchtime, hillcoeff", switchtime, hillcoeff)) + 
  stat_function(fun = function(.x)              totalSOPs*(.x/switchtime)^hillcoeff / ((.x/switchtime)^(hillcoeff) + 1) , colour = "red", size = 2   ) 
pdf("cumul_counts/count_SOP_hillfunction.pdf")
print(myplot)
dev.off()


## count SOPs anywhere (Ana segments extra ones)
SOPs_anywhere <- cellinfoDB %>% filter(cell_id %in% SOP_cell_id$cell_id) %>% select(cell_id,first_occ)
count_SOP_anywhere <- frames %>% select(frame)
# cross join to get every combination of frame and  times
count_SOP_anywhere <- merge(x = count_SOP_anywhere, y = SOPs_anywhere, by = NULL)
# then filter
count_SOP_anywhere <- count_SOP_anywhere %>% filter(first_occ < frame)
count_SOP_anywhere <- count_SOP_anywhere %>% select(frame) %>% group_by(frame) %>% summarise(count = n())
count_SOP_anywhere$dev_time <- count_SOP_anywhere$frame*2.5/60
count_SOP_anywhere <- count_SOP_anywhere %>% select(frame,dev_time,count)
# write 
write.csv(count_SOP_anywhere,file="cumul_counts/count_SOP_anywhere.csv")