## FOR posterior.

## Make a subfolder within core/posterior called kernSize1.
## put shear data in but with kernSize 1. Maybe iso too. 

dir.create("core")
dir.create("core/posterior")
dir.create("core/posterior/kernSize1")

## THIS VERSION IS FOR posterior. Do that first then make other versions.
## Append all things with _posterior.


## %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% #### %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% ##

load("time/roi_bt/roiCellsBT.RData")
roiBothNests <- roiCellsBT %>% filter(roi == "anterior" | roi == "posterior")
roiposterior <- roiCellsBT %>% filter(roi == "posterior")

## CDxx and CDxy with kernsize = 1
avgCDNematic <- multi_db_query(movieDirs, mqf_cg_roi_unit_nematics_CD, "posterior", kernSize = 1)
avgCDNematic <- avgCDNematic %>% select(frame,dev_time,cgCDxx_smooth,cgCDxy_smooth)
#exclude NA
avgCDNematic <- avgCDNematic %>% filter(is.na(cgCDxx_smooth) == FALSE) %>% filter(is.na(cgCDxy_smooth) == FALSE)
write.csv(avgCDNematic,file="core/posterior/kernSize1/avgCDNematic.csv")

## SHEAR WITH KERNSIZE= 1
# Shear Stuff (run sm shear_calc with correct roi_bt first!)
# SHEAR
selectedRois <- "posterior"
shearData <- multi_db_query(movieDirs, mqf_cg_roi_rate_shear, selectedRois, kernSize = 1)

shearRateSlim <- subset(shearData, (tensor=="CEwithCT" | tensor=="correlationEffects" |
                                      tensor=="nu" | tensor=="ShearT1" | 
                                      tensor=="ShearT2" | tensor=="ShearCD" | tensor=="sumContrib"))
shearRateSlim$tensor <- factor(shearRateSlim$tensor, 
                               levels=c("ShearCD", "CEwithCT", "correlationEffects",
                                        "nu", "ShearT1", "ShearT2", "sumContrib"),
                               labels=c("cell_division", "cell_elongation_change",
                                        "correlation_effects","total_shear","T1", "T2", "sumContrib"))

# interpolate data
deltaT=150
shearRateInterpolated <- shearRateSlim %>% 
  align_movie_start(movieDirs) %>%
  select(-c(xy,yx,yy,xy.ma,yx.ma,yy.ma, TimeInt.ma,
            phi, norm,time_sec,timeInt_sec,closestFrame,time_shift)) %>%
  mutate(min_dev_time=min(dev_time),
         max_dev_time=max(dev_time)) %>% 
  group_by(movie, roi, tensor) %>%
  do({
    with(., approx(dev_time, xx.ma,
                   xout = seq(min_dev_time[1], max_dev_time[1],
                              by = deltaT/3600), method = "linear")) %>% as.df()
  }) %>%
  rename(dev_time=x, XX=y) %>% 
  filter(!is.na(XX)) %>%
  ungroup() %>% mutate(movieNb=length(unique(movie))) %>% 
  group_by(roi, tensor, dev_time) %>%
  # Make sure that further calculations will be done on values present in all compared movies
  filter(n()==movieNb) %>% ungroup()

# average data between the 3 movies amongst ROI
shearRateSummary <- shearRateInterpolated %>%
  group_by(roi, tensor, dev_time) %>%
  summarise(xx.avg=mean(XX), xx.sd=sd(XX))

shearCumSumSummary <- shearRateInterpolated %>%
  group_by(movie, roi, tensor) %>%
  mutate(timeInt=c(0,diff(dev_time)),cumSum_xx=cumsum(XX*timeInt)) %>%
  group_by(roi, tensor, dev_time) %>%
  summarise(xxCumSum.avg=mean(cumSum_xx, na.rm = F), xxCumSum.sd=sd(cumSum_xx, na.rm = F))


## %% ISO WITH KERNSIZE = 1
# IsoContrib
isoContrib <- multi_db_query(movieDirs, mqf_cg_roi_rate_isotropic_contrib, c("posterior"), kernSize = 1) 
deltaT=150 # sampling (150 seconds WTs etc. )
avgIsoDefRateInterpolated <- isoContrib %>%
  align_movie_start(movieDirs) %>%
  mutate(min_dev_time=min(dev_time),
         max_dev_time=max(dev_time)) %>% 
  group_by(movie, roi, isoContrib) %>%
  # here, we do a linear interpolation of the data (60 sec per point)
  do({
    with(., approx(dev_time, value.ma,
                   xout = seq(min_dev_time[1], max_dev_time[1],
                              by = deltaT/3600), method = "linear")) %>% as.df()
  }) %>%
  rename(dev_time=x, value.ma=y) %>%
  filter(!is.na(value.ma)) %>%
  ungroup() %>% mutate(movieNb=length(unique(movie))) %>% 
  group_by(roi, isoContrib, dev_time) %>%
  # Make sure that further calculations will be done on values present in all compared movies
  filter(n()==movieNb) %>% ungroup()

# average data between the 3 movies amongst ROI  
avgIsoDefRateSummary <- avgIsoDefRateInterpolated %>%
  group_by(roi, isoContrib, dev_time) %>%
  summarise(value.avg=mean(value.ma), value.sd=sd(value.ma))

avgIsoDefCum <- avgIsoDefRateInterpolated %>%
  group_by(movie, roi, isoContrib) %>%
  mutate(timeInt=c(0,diff(dev_time)), value.cumsum=cumsum(value.ma*timeInt)) %>% 
  group_by(roi, isoContrib, dev_time) %>%
  summarise(cumsum.avg=mean(value.cumsum), cumsum.sd=sd(value.cumsum))







## %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% ## 
## CSVs ##
write.csv(shearCumSumSummary,file="core/posterior/kernSize1/shearCumSumSummary.csv")
write.csv(shearRateSummary,file="core/posterior/kernSize1/shearRateSummary.csv")

write.csv(avgIsoDefRateSummary,file="core/posterior/kernSize1/avgIsoDefRateSummary.csv")
write.csv(avgIsoDefCum,file="core/posterior/kernSize1/avgIsoDefCum.csv")

## %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% ##
## PDF ##
# shear deformation rate. symmetric y axis.
myplot <- ggplot(shearRateSummary, aes(dev_time, xx.avg, color=tensor)) +
  geom_line(size=2) + 
  theme(text = element_text(size = 18)) +
  geom_ribbon(aes(ymin=(xx.avg-xx.sd), ymax=(xx.avg+xx.sd), fill=tensor),
              alpha=0.2, linetype="dotted", size=0.2) +
  xlab("Time (h)")+
  ylab(expression(paste("rate xx (",h^-1,")"))) +
  scale_color_manual(values=shearColors) +
  scale_fill_manual(values=shearColors) +
  ylim((0-max(abs(shearRateSummary$xx.avg))),(0+max(abs(shearRateSummary$xx.avg)))) +
  ggtitle("shear rates xx kS=1")
pdf("core/posterior/kernSize1/shear_rate_posterior.pdf")
print(myplot)
dev.off()

# shear deformation cumul
myplot <- ggplot(shearCumSumSummary, aes(dev_time, xxCumSum.avg, color=tensor)) +
  geom_line(size=2) + 
  theme(text = element_text(size = 18)) +
  geom_ribbon(aes(ymin=(xxCumSum.avg-xxCumSum.sd), ymax=(xxCumSum.avg+xxCumSum.sd), fill=tensor),
              alpha=0.2, linetype="dotted", size=0.2) +
  xlab("Time (h)")+
  ylab(expression(paste("shear xx cumul"))) +
  scale_color_manual(values=shearColors) +
  scale_fill_manual(values=shearColors) +
  ylim((0-max(abs(shearCumSumSummary$xxCumSum.avg))),(0+max(abs(shearCumSumSummary$xxCumSum.avg)))) +
  ggtitle("cumul shear kS=1")
pdf("core/posterior/kernSize1/shear_cumul_posterior.pdf")
print(myplot)
dev.off()


# avgisodef cumulative. -1 lower limit on Y to keep account of exrtrusion etc. 
myplot <- ggplot(avgIsoDefCum, aes(dev_time, cumsum.avg, color=isoContrib)) +
  geom_line(size=2) + 
  theme(text = element_text(size = 18)) +
  geom_ribbon(aes(ymin=(cumsum.avg-cumsum.sd), ymax=(cumsum.avg+cumsum.sd), fill=isoContrib),
              alpha=0.2, linetype="dotted", size=0.2) +
  xlab("Time (h)")+
  ylab(expression(paste("Cumulative deformation"))) +
  scale_color_manual(values=isotropColors) +
  scale_fill_manual(values=isotropColors) +
  ylim(-1,NA) + 
  ggtitle("cumulative isotropic deformation")
pdf("core/posterior/kernSize1/isotropic_cumul_posterior.pdf")
print(myplot)
dev.off()

# avgisodef rate. symmetric y axis
myplot <- ggplot(avgIsoDefRateSummary, aes(dev_time, value.avg, color=isoContrib)) +
  geom_line(size=2) + 
  theme(text = element_text(size = 18)) +
  geom_ribbon(aes(ymin=(value.avg-value.sd), ymax=(value.avg+value.sd), fill=isoContrib),
              alpha=0.2, linetype="dotted", size=0.2) +
  xlab("Time (h)")+
  ylab(expression(paste("deformation rate (",h^-1,")"))) +
  scale_color_manual(values=isotropColors) +
  scale_fill_manual(values=isotropColors) +
  ylim((0-max(abs(avgIsoDefRateSummary$value.avg))),(0+max(abs(avgIsoDefRateSummary$value.avg)))) + 
  ggtitle("rates of isotropic deformation")
pdf("core/posterior/kernSize1/isotropic_rate_posterior.pdf")
print(myplot)
dev.off()


## T1 Rate with 1 frame time resolution %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# T1 RATE posterior but irrespective of direction.
T1rate_posterior <- multi_db_query(movieDirs, mqf_cg_roi_rate_T1, "posterior") %>% 
  chunk_time_into_intervals(deltaT = 150) %>%
  group_by(movie, roi,interval_mid) %>%
  summarise(avgT1rate=mean(cell_topo_rate),
            semT1=se(cell_topo_rate),
            time_sec=interval_mid[1],
            dev_time=mean(dev_time))

write.csv(T1rate_posterior,file="core/posterior/kernSize1/T1rate_posterior.csv")

myplot <- ggplot(T1rate_posterior, aes(dev_time, avgT1rate)) + 
  geom_line(size = 2)+
  geom_point(size=2, color="black") +
  theme(text = element_text(size = 18)) +
  geom_errorbar(aes(ymin=(avgT1rate-semT1), ymax=(avgT1rate+semT1)),
                size=1, width=1, color="black") +
  ylab(expression(paste("T1 rate [", cell^-1, h^-1,"]"))) + 
  scale_y_continuous(limits = c(0,NA)) + 
  ggtitle("T1 rate +- sem")
pdf("core/posterior/kernSize1/T1rate_posterior.pdf")
print(myplot)
dev.off()


#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
## SHEAR XY ADDITION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# SHEAR
selectedRois <- c("posterior")
shearData <- multi_db_query(movieDirs, mqf_cg_roi_rate_shear, selectedRois, kernSize = 1)

shearRateSlim <- subset(shearData, (tensor=="CEwithCT" | tensor=="correlationEffects" |
                                      tensor=="nu" | tensor=="ShearT1" | 
                                      tensor=="ShearT2" | tensor=="ShearCD"))
shearRateSlim$tensor <- factor(shearRateSlim$tensor, 
                               levels=c("ShearCD", "CEwithCT", "correlationEffects",
                                        "nu", "ShearT1", "ShearT2"),
                               labels=c("cell_division", "cell_elongation_change",
                                        "correlation_effects","total_shear","T1", "T2"))

# interpolate data
deltaT=150
shearRateInterpolated <- shearRateSlim %>% 
  align_movie_start(movieDirs) %>%
  select(-c(yx,yy,yx.ma,yy.ma, TimeInt.ma,
            phi, norm,time_sec,timeInt_sec,closestFrame,time_shift)) %>%
  mutate(min_dev_time=min(dev_time),
         max_dev_time=max(dev_time)) %>% 
  group_by(movie, roi, tensor) %>%
  do({
    with(., approx(dev_time, xy.ma,
                   xout = seq(min_dev_time[1], max_dev_time[1],
                              by = deltaT/3600), method = "linear")) %>% as.df()
  }) %>%
  rename(dev_time=x, XY=y) %>% 
  filter(!is.na(XY)) %>%
  ungroup() %>% mutate(movieNb=length(unique(movie))) %>% 
  group_by(roi, tensor, dev_time) %>%
  # Make sure that further calculations will be done on values present in all compared movies
  filter(n()==movieNb) %>% ungroup()

# average data between the 3 movies amongst ROI
shearRateSummary_XY <- shearRateInterpolated %>%
  group_by(roi, tensor, dev_time) %>%
  summarise(xy.avg=mean(XY), xy.sd=sd(XY))

shearCumSumSummary_XY <- shearRateInterpolated %>%
  group_by(movie, roi, tensor) %>%
  mutate(timeInt=c(0,diff(dev_time)),cumSum_xy=cumsum(XY*timeInt)) %>%
  group_by(roi, tensor, dev_time) %>%
  summarise(xyCumSum.avg=mean(cumSum_xy, na.rm = F), xyCumSum.sd=sd(cumSum_xy, na.rm = F))


write.csv(shearCumSumSummary_XY,file="core/posterior/kernSize1/shearCumSumSummary_XY.csv")
write.csv(shearRateSummary_XY,file="core/posterior/kernSize1/shearRateSummary_XY.csv")
## SHEAR XY ADDITION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
