dir.create("lifetime_spatial")



### script to do brief analysis of the new quadrant

#useful function
every_nth <- function(x, nth, empty = TRUE, inverse = FALSE) 
{
  if (!inverse) {
    if(empty) {
      x[1:nth == 1] <- ""
      x
    } else {
      x[1:nth != 1]
    }
  } else {
    if(empty) {
      x[1:nth != 1] <- ""
      x
    } else {
      x[1:nth == 1]
    }
  }
}
# egg to allow absolute panel size setting in ggplot2?
#install.packages("egg")
library("egg")

load("time/roi_BT/SOP_cell_id.RData")
load("time/topochanges/CellNeighbors.RData")
load("time/roi_bt/lgRoiSmoothed.RData")
load("time/roi_bt/roiCellsBT.RData")
roiAnterior <- roiCellsBT %>% filter(roi == "anterior")
roiPosterior <- roiCellsBT %>% filter(roi == "posterior")
roiBothNests <- roiCellsBT %>% filter(roi == "anterior" | roi == "posterior")
roiHistoNoborder <- lgRoiSmoothed %>% filter(roi == "anterior")

### NEW INSERT. GS suggests a video where each cell (div-div) is coloured with its age as a proportion of its lifetime
### Do it for the whole anterior nest.
anterior_lifetimes <- cellinfoDB %>% filter(cell_id %in% roiAnterior$cell_id) %>% filter(appears_by == "Division" & disappears_by == "Division") %>% mutate(lifetime = last_occ-first_occ) %>% select(cell_id,first_occ,lifetime)
anterior_lifetimes_csv <- anterior_lifetimes %>% mutate(first_occ = first_occ *2.5/60, lifetime=lifetime*2.5/60)
write.csv(anterior_lifetimes_csv,file="lifetime_spatial/anterior_lifetimes.csv")

anterior_cellcyclefrac <- cellsDB %>% dt.merge(anterior_lifetimes,by="cell_id")
anterior_cellcyclefrac <- anterior_cellcyclefrac %>% mutate(frac = (frame-first_occ)/lifetime)
cellshapes_anterior_cellcyclefrac <- cellshapes %>% dt.merge(anterior_cellcyclefrac,by=c("frame","cell_id"))
render_movie(cellshapes_anterior_cellcyclefrac, "lifetime_spatial/cellshapes_anterior_cellcyclefrac.mp4", list(
  # geometrical layer to represent cells as polygons
  geom_polygon(aes(x_pos, y_pos, group=cell_id, fill = frac), alpha=0.75), # this was 0.75 before, trying this for overlaying multiple with transparency. see evernote.
  scale_fill_gradientn(name="cycle frac",
                       colors  = jet.colors(7),
                       # ignore tails of distribution
                       limits=c(0,1),
                       na.value = "black")
))

## whole posterior
### Do it for the whole anterior nest.
posterior_lifetimes <- cellinfoDB %>% filter(cell_id %in% roiPosterior$cell_id) %>% filter(appears_by == "Division" & disappears_by == "Division") %>% mutate(lifetime = last_occ-first_occ) %>% select(cell_id,first_occ,lifetime)
posterior_cellcyclefrac <- cellsDB %>% dt.merge(posterior_lifetimes,by="cell_id")
posterior_cellcyclefrac <- posterior_cellcyclefrac %>% mutate(frac = (frame-first_occ)/lifetime)
cellshapes_posterior_cellcyclefrac <- cellshapes %>% dt.merge(posterior_cellcyclefrac,by=c("frame","cell_id"))
render_movie(cellshapes_posterior_cellcyclefrac, "lifetime_spatial/cellshapes_posterior_cellcyclefrac.mp4", list(
  # geometrical layer to represent cells as polygons
  geom_polygon(aes(x_pos, y_pos, group=cell_id, fill = frac), alpha=0.75), # this was 0.75 before, trying this for overlaying multiple with transparency. see evernote.
  scale_fill_gradientn(name="cycle frac",
                       colors  = jet.colors(7),
                       # ignore tails of distribution
                       limits=c(0,1),
                       na.value = "black")
))

## anterior + posterior
### Do it for the whole anterior nest.
antandpos_lifetimes <- cellinfoDB %>% filter(cell_id %in% roiBothNests$cell_id) %>% filter(appears_by == "Division" & disappears_by == "Division") %>% mutate(lifetime = last_occ-first_occ) %>% select(cell_id,first_occ,lifetime)
antandpos_cellcyclefrac <- cellsDB %>% dt.merge(antandpos_lifetimes,by="cell_id")
antandpos_cellcyclefrac <- antandpos_cellcyclefrac %>% mutate(frac = (frame-first_occ)/lifetime)
cellshapes_antandpos_cellcyclefrac <- cellshapes %>% dt.merge(antandpos_cellcyclefrac,by=c("frame","cell_id"))
render_movie(cellshapes_antandpos_cellcyclefrac, "lifetime_spatial/cellshapes_antandpos_cellcyclefrac.mp4", list(
  # geometrical layer to represent cells as polygons
  geom_polygon(aes(x_pos, y_pos, group=cell_id, fill = frac), alpha=0.75), # this was 0.75 before, trying this for overlaying multiple with transparency. see evernote.
  scale_fill_gradientn(name="cycle frac",
                       colors  = jet.colors(7),
                       # ignore tails of distribution
                       limits=c(0,1),
                       na.value = "black")
))
### END INSERT




## IDEA. for each cell in the anterior nest, characterise it per frame by its distance to the current anterior COM
anterior_cells_disttoCOM <- cellsDB %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(frame,cell_id,center_x,center_y,area) 



anterior_COM <- cellsDB %>% select(frame,cell_id,area,center_x,center_y) %>% filter(cell_id %in% roiAnterior$cell_id)
anterior_COM$center_x_area <- anterior_COM$area*anterior_COM$center_x
anterior_COM$center_y_area <- anterior_COM$area*anterior_COM$center_y
anterior_COM <- anterior_COM %>% group_by(frame) %>% summarise(COM_x = sum(center_x_area) / sum(area), COM_y = sum(center_y_area) / sum(area))

anterior_cells_disttoCOM <- anterior_cells_disttoCOM %>% dt.merge(anterior_COM,by="frame")
anterior_cells_disttoCOM$dist <- sqrt( (anterior_cells_disttoCOM$center_x - anterior_cells_disttoCOM$COM_x)^2 +  (anterior_cells_disttoCOM$center_y - anterior_cells_disttoCOM$COM_y)^2 )

# make a list of div-div anterior cells visible for whole time.
anterior_framesvisible <- anterior_cells_disttoCOM %>% group_by(cell_id) %>% summarise(framesvisible = n())
anterior_divdiv <- cellinfoDB %>% filter(cell_id %in% roiAnterior$cell_id) %>% filter(appears_by == "Division" & disappears_by == "Division") %>% mutate(lifetime = last_occ - first_occ) %>% select(cell_id,first_occ,lifetime) %>% dt.merge(anterior_framesvisible,by="cell_id")
anterior_divdiv <- anterior_divdiv %>% filter(lifetime == framesvisible - 1)

anterior_cells_meandistCOM <- anterior_cells_disttoCOM %>% group_by(cell_id) %>% summarise(meanCOMdist = mean(dist))
# put back in frame info
anterior_cells_meandistCOM <- cellsDB %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(frame,cell_id,center_x,center_y,area) %>% dt.merge(anterior_cells_meandistCOM,by="cell_id")

## now get the top 33% and bottom 33% for meandistCOM on a perframe basis.
percentiles_perframe <- anterior_cells_meandistCOM %>% group_by(frame) %>% summarise(meanmeandistCOM = mean(meanCOMdist), percentile_33 = quantile(meanCOMdist,0.3333), percentile_66 = quantile(meanCOMdist,0.6666))

## merge back so we can label cells by percentile
anterior_cells_meandistCOM <- anterior_cells_meandistCOM %>% dt.merge(percentiles_perframe,by="frame")

## label percentile 
anterior_cells_COMpercentile <- anterior_cells_meandistCOM %>% mutate(series = as.integer(meanCOMdist > percentile_33) + as.integer(meanCOMdist > percentile_66))

## make a test movie of cells labelled like this
cellshapes_anterior_cells_COMpercentile <- anterior_cells_COMpercentile %>% select(frame,cell_id,series) %>% dt.merge(cellshapes,by=c("frame","cell_id"))

# render_movie(cellshapes_anterior_cells_COMpercentile, "lifetime_spatial/cellshapes_anterior_cells_COMpercentile.mp4", list( 
#   # geometrical layer to represent cells as polygons
#   geom_polygon(aes(x_pos, y_pos, group=cell_id, fill = series), alpha=0.75), # this was 0.75 before, trying this for overlaying multiple with transparency. see evernote. 
#   scale_fill_gradientn(name="percentile COM dist",
#                        colors  = jet.colors(7),
#                        # ignore tails of distribution
#                        limits=c(0,2),
#                        na.value = "black")
# ))

## doesn't fit the anisotropy of the anterior nest very well. 

### okay that doesn't work.

## now instead: use non-anterior neighbours of anterior as a list of boundary cells, then define the minimum distance to one of those
## as a property of anterior cells.
boundarycells <- cellNeighbors %>% filter(cell_id %in% roiAnterior$cell_id & !(neighbor_cell_id %in% roiAnterior$cell_id)) %>% select(frame,cell_id)
#cell_id is the one that is INSIDE anterior (changed, such that the outer layer of anterior cells defines the boundary. more consistent than LECs)
#get centroids of boundary cells
boundarycells <- cellsDB %>% select(frame,cell_id,center_x,center_y) %>% dt.merge(boundarycells,by = c("frame","cell_id"))
boundarycells <- boundarycells %>% rename(b_cell_id=cell_id,b_center_x = center_x, b_center_y = center_y)

anterior_disttoboundary <- cellsDB %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(frame,cell_id,center_x,center_y,area)
anterior_disttoboundary <- anterior_disttoboundary %>% dt.merge(boundarycells,by="frame",allow.cartesian=TRUE)

anterior_disttoboundary$distsq <- (anterior_disttoboundary$center_x - anterior_disttoboundary$b_center_x)^2 + (anterior_disttoboundary$center_y - anterior_disttoboundary$b_center_y)^2

anterior_disttoboundary <- anterior_disttoboundary %>% group_by(frame,cell_id) %>% summarise(mindistsq = min(distsq))
anterior_disttoboundary <- anterior_disttoboundary %>% mutate(mindist = sqrt(mindistsq)) %>% select(-mindistsq)

## now. DON'T average the dist toboundary over hte lifetime of the cell. no point. just worry what is the distance to boundary in the frame in which the cell is born when it comes to it.
distboundary_percentiles <- anterior_disttoboundary %>% group_by(frame) %>% summarise(meandist = mean(mindist), percentile_33 = quantile(mindist,0.3333), percentile_66 = quantile(mindist,0.6666))

# merge back
anterior_disttoboundary <- anterior_disttoboundary %>% dt.merge(distboundary_percentiles,by="frame")

anterior_disttoboundary <- anterior_disttoboundary %>% mutate(series = as.integer(mindist > percentile_33) + as.integer(mindist > percentile_66))

cellshapes_anterior_disttoboundary <- anterior_disttoboundary %>% select(frame,cell_id,series) %>% dt.merge(cellshapes,by=c("frame","cell_id"))


# render_movie(cellshapes_anterior_disttoboundary, "lifetime_spatial/cellshapes_anterior_disttoboundary_percentile.mp4", list(
#   # geometrical layer to represent cells as polygons
#   geom_polygon(aes(x_pos, y_pos, group=cell_id, fill = series), alpha=0.75), # this was 0.75 before, trying this for overlaying multiple with transparency. see evernote.
#   scale_fill_gradientn(name="percentile COM dist",
#                        colors  = jet.colors(7),
#                        # ignore tails of distribution
#                        limits=c(0,2),
#                        na.value = "black")
# ))

## okay that works well.
## now let's do a first attempt to measure lifetime in the 0 and 2 series percentiles

lifetime_anterior_disttoboundary <- cellinfoDB %>% filter(cell_id %in% anterior_divdiv$cell_id) %>% mutate(lifetime = last_occ - first_occ) %>% select(cell_id,first_occ,lifetime) 
lifetime_anterior_disttoboundary <- lifetime_anterior_disttoboundary %>% dt.merge(anterior_disttoboundary,by="cell_id")
#restrict to frame = first_occ so we find the percentile when it was born.
lifetime_anterior_disttoboundary <- lifetime_anterior_disttoboundary %>% filter(frame == first_occ)

## now split into tables for percentiles to work out mean lifetime in time bins.
lifetimes_sub33pc <- lifetime_anterior_disttoboundary %>% filter(series == 0) %>% select(cell_id,first_occ,lifetime,mindist)
lifetimes_sup66pc <- lifetime_anterior_disttoboundary %>% filter(series == 2) %>% select(cell_id,first_occ,lifetime,mindist)

## copy lifetimes trend code
lifetimes_trend_sub33pc_25 <- frames %>% select(frame) %>% filter(frame %% 25 == 0)
lifetimes_trend_sub33pc_25 <- lifetimes_trend_sub33pc_25 %>% rename(min_frame = frame)
lifetimes_trend_sub33pc_25$max_frame <- lifetimes_trend_sub33pc_25$min_frame + 25 
for (row in 1:nrow(lifetimes_trend_sub33pc_25)) {
  lifetimes_trend_sub33pc_25[row,"n_div"] = lifetimes_sub33pc %>% filter(first_occ > lifetimes_trend_sub33pc_25[row,"min_frame"] & first_occ < lifetimes_trend_sub33pc_25[row,"max_frame"]) %>% nrow()
}
for (row in 1:nrow(lifetimes_trend_sub33pc_25)) {
  lifetimes_trend_sub33pc_25[row,"mean_life"] = (lifetimes_sub33pc %>% filter(first_occ > lifetimes_trend_sub33pc_25[row,"min_frame"] & first_occ < lifetimes_trend_sub33pc_25[row,"max_frame"]))$lifetime %>% mean()
}
for (row in 1:nrow(lifetimes_trend_sub33pc_25)) {
  lifetimes_trend_sub33pc_25[row,"sd_life"] = (lifetimes_sub33pc %>% filter(first_occ > lifetimes_trend_sub33pc_25[row,"min_frame"] & first_occ < lifetimes_trend_sub33pc_25[row,"max_frame"]))$lifetime %>% sd()
}
lifetimes_trend_sub33pc_25$dev_time <- ((lifetimes_trend_sub33pc_25$min_frame + lifetimes_trend_sub33pc_25$max_frame)/2) * 2.5/60
lifetimes_trend_sub33pc_25 <- lifetimes_trend_sub33pc_25 %>% select(min_frame,max_frame,dev_time,n_div,mean_life,sd_life)
lifetimes_trend_sub33pc_25$mean_life <- lifetimes_trend_sub33pc_25$mean_life*2.5/60
lifetimes_trend_sub33pc_25$sd_life <- lifetimes_trend_sub33pc_25$sd_life*2.5/60

#
lifetimes_trend_sup66pc_25 <- frames %>% select(frame) %>% filter(frame %% 25 == 0)
lifetimes_trend_sup66pc_25 <- lifetimes_trend_sup66pc_25 %>% rename(min_frame = frame)
lifetimes_trend_sup66pc_25$max_frame <- lifetimes_trend_sup66pc_25$min_frame + 25 
for (row in 1:nrow(lifetimes_trend_sup66pc_25)) {
  lifetimes_trend_sup66pc_25[row,"n_div"] = lifetimes_sup66pc %>% filter(first_occ > lifetimes_trend_sup66pc_25[row,"min_frame"] & first_occ < lifetimes_trend_sup66pc_25[row,"max_frame"]) %>% nrow()
}
for (row in 1:nrow(lifetimes_trend_sup66pc_25)) {
  lifetimes_trend_sup66pc_25[row,"mean_life"] = (lifetimes_sup66pc %>% filter(first_occ > lifetimes_trend_sup66pc_25[row,"min_frame"] & first_occ < lifetimes_trend_sup66pc_25[row,"max_frame"]))$lifetime %>% mean()
}
for (row in 1:nrow(lifetimes_trend_sup66pc_25)) {
  lifetimes_trend_sup66pc_25[row,"sd_life"] = (lifetimes_sup66pc %>% filter(first_occ > lifetimes_trend_sup66pc_25[row,"min_frame"] & first_occ < lifetimes_trend_sup66pc_25[row,"max_frame"]))$lifetime %>% sd()
}
lifetimes_trend_sup66pc_25$dev_time <- ((lifetimes_trend_sup66pc_25$min_frame + lifetimes_trend_sup66pc_25$max_frame)/2) * 2.5/60
lifetimes_trend_sup66pc_25 <- lifetimes_trend_sup66pc_25 %>% select(min_frame,max_frame,dev_time,n_div,mean_life,sd_life)
lifetimes_trend_sup66pc_25$mean_life <- lifetimes_trend_sup66pc_25$mean_life*2.5/60
lifetimes_trend_sup66pc_25$sd_life <- lifetimes_trend_sup66pc_25$sd_life*2.5/60


## plot 
myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  #
  geom_errorbar(data=lifetimes_trend_sub33pc_25,aes(dev_time,ymin=(mean_life-sd_life), ymax=(mean_life+sd_life)),size=0.8, width=20/40,color="red") +
  geom_point(data=lifetimes_trend_sub33pc_25,aes(dev_time,mean_life),size=0.8,color="red") +
  geom_line(data=lifetimes_trend_sub33pc_25,aes(dev_time,mean_life),size=0.6,color="red") +
  #
  geom_errorbar(data=lifetimes_trend_sup66pc_25,aes(dev_time,ymin=(mean_life-sd_life), ymax=(mean_life+sd_life)),size=0.8, width=20/40,color="blue") +
  geom_point(data=lifetimes_trend_sup66pc_25,aes(dev_time,mean_life),size=0.8,color="blue") +
  geom_line(data=lifetimes_trend_sup66pc_25,aes(dev_time,mean_life),size=0.6,color="blue") +
  #
  scale_color_manual(values=movieColors) +
  scale_fill_manual(values=movieColors) +
  #scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  #ylim(0,0.4) +
  xlab("Time unadjusted")+
  ylab(expression(paste("Cell cycle time (hr)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("lifetime_spatial/sub33_vs_sup66_percentile_lifetimes.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)


##### ALTERNATIVE DEFINITION OF different percentile groups. Split into percentiles in the first frame, then go via lineages.
frame0_disttoboundary <- anterior_disttoboundary %>% filter(frame == 0)
lgs_frame0_sub33 <- frame0_disttoboundary %>% filter(series == 0) %>% select(cell_id,series) %>% dt.merge(cellinfoDB,by="cell_id") %>% select(lineage_group,series) %>% unique()
lgs_frame0_sup33 <- frame0_disttoboundary %>% filter(series == 1) %>% select(cell_id,series) %>% dt.merge(cellinfoDB,by="cell_id") %>% select(lineage_group,series) %>% unique()
lgs_frame0_sup66 <- frame0_disttoboundary %>% filter(series == 2) %>% select(cell_id,series) %>% dt.merge(cellinfoDB,by="cell_id") %>% select(lineage_group,series) %>% unique()
lgs_frame0_series <- rbind(lgs_frame0_sub33,lgs_frame0_sup33,lgs_frame0_sup66)

lgs_percentiles_anterior <- cellinfoDB %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(cell_id,lineage_group) %>% dt.merge(lgs_frame0_series,by="lineage_group")

## make test movie
cellshapes_lgs_percentiles_anterior <- cellshapes %>% dt.merge(lgs_percentiles_anterior,by="cell_id")

# render_movie(cellshapes_lgs_percentiles_anterior, "lifetime_spatial/cellshapes_lgs_percentiles_anterior.mp4", list(
#   # geometrical layer to represent cells as polygons
#   geom_polygon(aes(x_pos, y_pos, group=cell_id, fill = series), alpha=0.75), # this was 0.75 before, trying this for overlaying multiple with transparency. see evernote.
#   scale_fill_gradientn(name="pc COM distfr0 lg",
#                        colors  = jet.colors(7),
#                        # ignore tails of distribution
#                        limits=c(0,2),
#                        na.value = "black")
# ))


## no this isn't working well either really. the problem is using the centroids of surrounding cells as a boundary. the LECs are big and their centroids are all over the place.
## re-do this script instead using the anterior boundary cells as the edge. 

## done that. now that lineage frame0 percentile one seems good. use that to make another version of the lifetimes trend. 

lifetime_lgs_percentiles_anterior <- cellinfoDB %>% filter(cell_id %in% anterior_divdiv$cell_id) %>% mutate(lifetime = last_occ - first_occ) %>% select(cell_id,first_occ,lifetime) 
lifetime_lgs_percentiles_anterior <- lifetime_lgs_percentiles_anterior %>% dt.merge(lgs_percentiles_anterior,by="cell_id")

lifetimes_fr0_sub33pc <- lifetime_lgs_percentiles_anterior %>% filter(series == 0) %>% select(cell_id,first_occ,lifetime,series)
lifetimes_fr0_sup66pc <- lifetime_lgs_percentiles_anterior %>% filter(series == 2) %>% select(cell_id,first_occ,lifetime,series)

## lifetimes trend
lifetimes_trend_fr0_sub33pc_25 <- frames %>% select(frame) %>% filter(frame %% 25 == 0)
lifetimes_trend_fr0_sub33pc_25 <- lifetimes_trend_fr0_sub33pc_25 %>% rename(min_frame = frame)
lifetimes_trend_fr0_sub33pc_25$max_frame <- lifetimes_trend_fr0_sub33pc_25$min_frame + 25 
for (row in 1:nrow(lifetimes_trend_fr0_sub33pc_25)) {
  lifetimes_trend_fr0_sub33pc_25[row,"n_div"] = lifetimes_fr0_sub33pc %>% filter(first_occ > lifetimes_trend_fr0_sub33pc_25[row,"min_frame"] & first_occ < lifetimes_trend_fr0_sub33pc_25[row,"max_frame"]) %>% nrow()
}
for (row in 1:nrow(lifetimes_trend_fr0_sub33pc_25)) {
  lifetimes_trend_fr0_sub33pc_25[row,"mean_life"] = (lifetimes_fr0_sub33pc %>% filter(first_occ > lifetimes_trend_fr0_sub33pc_25[row,"min_frame"] & first_occ < lifetimes_trend_fr0_sub33pc_25[row,"max_frame"]))$lifetime %>% mean()
}
for (row in 1:nrow(lifetimes_trend_fr0_sub33pc_25)) {
  lifetimes_trend_fr0_sub33pc_25[row,"sd_life"] = (lifetimes_fr0_sub33pc %>% filter(first_occ > lifetimes_trend_fr0_sub33pc_25[row,"min_frame"] & first_occ < lifetimes_trend_fr0_sub33pc_25[row,"max_frame"]))$lifetime %>% sd()
}
lifetimes_trend_fr0_sub33pc_25$dev_time <- ((lifetimes_trend_fr0_sub33pc_25$min_frame + lifetimes_trend_fr0_sub33pc_25$max_frame)/2) * 2.5/60
lifetimes_trend_fr0_sub33pc_25 <- lifetimes_trend_fr0_sub33pc_25 %>% select(min_frame,max_frame,dev_time,n_div,mean_life,sd_life)
lifetimes_trend_fr0_sub33pc_25$mean_life <- lifetimes_trend_fr0_sub33pc_25$mean_life*2.5/60
lifetimes_trend_fr0_sub33pc_25$sd_life <- lifetimes_trend_fr0_sub33pc_25$sd_life*2.5/60

#
lifetimes_trend_fr0_sup66pc_25 <- frames %>% select(frame) %>% filter(frame %% 25 == 0)
lifetimes_trend_fr0_sup66pc_25 <- lifetimes_trend_fr0_sup66pc_25 %>% rename(min_frame = frame)
lifetimes_trend_fr0_sup66pc_25$max_frame <- lifetimes_trend_fr0_sup66pc_25$min_frame + 25 
for (row in 1:nrow(lifetimes_trend_fr0_sup66pc_25)) {
  lifetimes_trend_fr0_sup66pc_25[row,"n_div"] = lifetimes_fr0_sup66pc %>% filter(first_occ > lifetimes_trend_fr0_sup66pc_25[row,"min_frame"] & first_occ < lifetimes_trend_fr0_sup66pc_25[row,"max_frame"]) %>% nrow()
}
for (row in 1:nrow(lifetimes_trend_fr0_sup66pc_25)) {
  lifetimes_trend_fr0_sup66pc_25[row,"mean_life"] = (lifetimes_fr0_sup66pc %>% filter(first_occ > lifetimes_trend_fr0_sup66pc_25[row,"min_frame"] & first_occ < lifetimes_trend_fr0_sup66pc_25[row,"max_frame"]))$lifetime %>% mean()
}
for (row in 1:nrow(lifetimes_trend_fr0_sup66pc_25)) {
  lifetimes_trend_fr0_sup66pc_25[row,"sd_life"] = (lifetimes_fr0_sup66pc %>% filter(first_occ > lifetimes_trend_fr0_sup66pc_25[row,"min_frame"] & first_occ < lifetimes_trend_fr0_sup66pc_25[row,"max_frame"]))$lifetime %>% sd()
}
lifetimes_trend_fr0_sup66pc_25$dev_time <- ((lifetimes_trend_fr0_sup66pc_25$min_frame + lifetimes_trend_fr0_sup66pc_25$max_frame)/2) * 2.5/60
lifetimes_trend_fr0_sup66pc_25 <- lifetimes_trend_fr0_sup66pc_25 %>% select(min_frame,max_frame,dev_time,n_div,mean_life,sd_life)
lifetimes_trend_fr0_sup66pc_25$mean_life <- lifetimes_trend_fr0_sup66pc_25$mean_life*2.5/60
lifetimes_trend_fr0_sup66pc_25$sd_life <- lifetimes_trend_fr0_sup66pc_25$sd_life*2.5/60

## plot 
## plot 
myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  #
  geom_errorbar(data=lifetimes_trend_fr0_sub33pc_25,aes(dev_time,ymin=(mean_life-sd_life), ymax=(mean_life+sd_life)),size=0.8, width=20/40,color="red") +
  geom_point(data=lifetimes_trend_fr0_sub33pc_25,aes(dev_time,mean_life),size=0.8,color="red") +
  geom_line(data=lifetimes_trend_fr0_sub33pc_25,aes(dev_time,mean_life),size=0.6,color="red") +
  #
  geom_errorbar(data=lifetimes_trend_fr0_sup66pc_25,aes(dev_time,ymin=(mean_life-sd_life), ymax=(mean_life+sd_life)),size=0.8, width=20/40,color="blue") +
  geom_point(data=lifetimes_trend_fr0_sup66pc_25,aes(dev_time,mean_life),size=0.8,color="blue") +
  geom_line(data=lifetimes_trend_fr0_sup66pc_25,aes(dev_time,mean_life),size=0.6,color="blue") +
  #
  scale_color_manual(values=movieColors) +
  scale_fill_manual(values=movieColors) +
  #scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  #ylim(0,0.4) +
  xlab("Time unadjusted")+
  ylab(expression(paste("Cell cycle time (hr)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("lifetime_spatial/fr0_sub33_vs_fr0_sup66_percentile_lifetimes.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)









#########################3 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#### OTHER VERSION FOR NIC T -- looking at regions that fuse with the top and bottom anterior nests

## Firstly need to get a custom roi made for posterior nest and the one from the top too. 
## first what would an ROI look like if it was appears by coming through frame boundary? MovedIntoMask
roiLEC <- cellinfoDB %>% filter(appears_by == "Unclassified") %>% filter(!(cell_id %in% roiBothNests$cell_id)) %>% filter(cell_id != 10000)
movedintomask <- cellinfoDB %>% filter(appears_by == "MovedIntoMask") %>% select(cell_id,first_occ) %>% filter(!(cell_id %in% roiLEC$cell_id))
## this is quite complicated to get. hmm. 
## further filters. Need it to be, in its first occ, closer to the top boundary than to any other boundary
movedintomask <- movedintomask %>% rename(frame = first_occ)
movedintomask <- movedintomask %>% dt.merge(cellsDB %>% select(cell_id,frame,center_x,center_y,area),by=c("frame","cell_id"))
movedintomask <- movedintomask %>% filter(center_y < (1008-center_y) & center_y < center_x & center_y < (1912-center_x)) 
## need it to have, in its first frame, area less than 3000 px say. 
movedintomask <- movedintomask %>% filter(area < 3000)
## pretty good already. now get all descendents too. find lineage group.
movedintomask <- cellinfoDB %>% select(cell_id, lineage_group) %>% dt.merge(movedintomask,by="cell_id")
descendants <- cellinfoDB %>% filter(!(cell_id %in% movedintomask$cell_id)) %>% filter(lineage_group %in% movedintomask$lineage_group) %>% select(cell_id)
movedintomask_and_descendants <- rbind(movedintomask %>% select(cell_id),descendants)

cellshapes_movedintomask_and_descendants <- cellshapes %>% dt.merge(movedintomask_and_descendants %>% select(cell_id),by="cell_id")
# render_movie(cellshapes_movedintomask_and_descendants, "cellshapes_movedintomask_and_descendants.mp4", list(
#   
#   # geometrical layer to represent cells as polygons
#   geom_polygon(aes(x_pos, y_pos, fill=roi, group=cell_id),  fill = "red", alpha=0.6)
# ))

## This seems pretty good, it has some holes but at least the first layer or two of posterior cells from the segment above is included, and I am just looking for min distances so that's good.
## now make a movie of this with the other rois.
roimovie_anterior <- roiBothNests %>% filter(roi == "anterior") %>% filter(!(cell_id %in% roiHistoNoborder$cell_id))
roimovie_anterior$roi <- "anterior"
roimovie_posterior <- roiBothNests %>% filter(roi == "posterior")
roimovie_posterior$roi <- "posterior"
roimovie_noborder <- roiHistoNoborder
roimovie_noborder$roi <- "noborder"
roimovie_topposterior <- movedintomask_and_descendants
roimovie_topposterior$roi <- "topposterior"

roimovie <- rbind(roimovie_anterior,roimovie_posterior,roimovie_noborder,roimovie_topposterior)
cellshapes_roimovie_w_topposterior <- cellshapes %>% dt.merge(roimovie, by = "cell_id")
# render_movie(cellshapes_roimovie_w_topposterior, "lifetime_spatial/cellshapes_roimovie_w_topposterior.mp4", list( 
#   # geometrical layer to represent cells as polygons
#   geom_polygon(aes(x_pos, y_pos, group=cell_id,fill = roi), alpha=0.65),
#   scale_fill_manual(values=c("anterior"="green", "posterior"="red","noborder" = "purple","topposterior" = "blue"))
# ))

### Okay so now to define 'near fusion' regions. find any (ever) neighbour of a posterior (or topposterior) cell, and every second neighbour.
## then define their lineages as the regions?

# first find neighbours of posterior (bottom)
pos_1stneighs <- cellNeighbors %>% filter(neighbor_cell_id %in% roiPosterior$cell_id) %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(cell_id) %>% unique()
# find 2nd neighs
pos_2ndneighs <- cellNeighbors %>% filter(neighbor_cell_id %in% pos_1stneighs$cell_id) %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(cell_id) %>% unique()

# combine together, then get lineages groups.
pos_neighlins <- rbind(pos_1stneighs,pos_2ndneighs)
pos_neighlins <- cellinfoDB %>% select(cell_id,lineage_group) %>% dt.merge(pos_neighlins,by="cell_id") %>% select(lineage_group) %>% unique()

# define a roi based on being in those lineages
pos_neigh_roi <- cellinfoDB %>% filter(lineage_group %in% pos_neighlins$lineage_group) %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(cell_id) %>% unique() %>% mutate(roi = "pos_neigh")
#movie to test
roimovie2 <- rbind(roimovie_posterior,roimovie_topposterior,pos_neigh_roi)
cellshapes_pos_neigh_roi_test <- cellshapes %>% dt.merge(roimovie2, by = "cell_id")

# render_movie(cellshapes_pos_neigh_roi_test, "lifetime_spatial/cellshapes_pos_neigh_roi_test.mp4", list(
#   # geometrical layer to represent cells as polygons
#   geom_polygon(aes(x_pos, y_pos, group=cell_id,fill = roi), alpha=0.65),
#   scale_fill_manual(values=c("pos_neigh"="white","anterior"="green", "posterior"="red","noborder" = "purple","topposterior" = "blue"))
# ))

## do same as above but for top posterior. 
# first find neighbours of posterior (top)
toppos_1stneighs <- cellNeighbors %>% filter(neighbor_cell_id %in% roimovie_topposterior$cell_id) %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(cell_id) %>% unique()
# find 2nd neighs
toppos_2ndneighs <- cellNeighbors %>% filter(neighbor_cell_id %in% toppos_1stneighs$cell_id) %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(cell_id) %>% unique()

# combine together, then get lineages groups.
toppos_neighlins <- rbind(toppos_1stneighs,toppos_2ndneighs)
toppos_neighlins <- cellinfoDB %>% select(cell_id,lineage_group) %>% dt.merge(toppos_neighlins,by="cell_id") %>% select(lineage_group) %>% unique()

# define a roi based on being in those lineages
toppos_neigh_roi <- cellinfoDB %>% filter(lineage_group %in% toppos_neighlins$lineage_group) %>% filter(cell_id %in% roiAnterior$cell_id) %>% select(cell_id) %>% unique() %>% mutate(roi = "toppos_neigh")

## test
roimovie2 <- rbind(roimovie_posterior,roimovie_topposterior,pos_neigh_roi, toppos_neigh_roi)

cellshapes_pos_neigh_roi_test <- cellshapes %>% dt.merge(roimovie2, by = "cell_id")

render_movie(cellshapes_pos_neigh_roi_test, "lifetime_spatial/cellshapes_pos_neigh_roi_test.mp4", list(
  # geometrical layer to represent cells as polygons
  geom_polygon(aes(x_pos, y_pos, group=cell_id,fill = roi), alpha=0.65),
  scale_fill_manual(values=c("toppos_neigh"="blue", "pos_neigh"="red","anterior"="green", "posterior"="white","noborder" = "purple","topposterior" = "white"))
))

## looks good. Now make a list of anterior-but-not-in-fusion regions
anterior_not_posneighs <- roiAnterior %>% filter(!(cell_id %in% pos_neigh_roi$cell_id) & !(cell_id %in% toppos_neigh_roi$cell_id))

## Now analyse lifetime trends of these three regions separately. posneigh, toppos neigh, and main anterior. %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

## copy lifetimes trend code
lifetimes_posneigh <- cellinfoDB %>% filter(cell_id %in% pos_neigh_roi$cell_id) %>% filter(cell_id %in% anterior_divdiv$cell_id) %>% select(first_occ,last_occ) %>% mutate(lifetime = last_occ-first_occ)

lifetimes_trend_posneigh_25 <- frames %>% select(frame) %>% filter(frame %% 25 == 0)
lifetimes_trend_posneigh_25 <- lifetimes_trend_posneigh_25 %>% rename(min_frame = frame)
lifetimes_trend_posneigh_25$max_frame <- lifetimes_trend_posneigh_25$min_frame + 25 
for (row in 1:nrow(lifetimes_trend_posneigh_25)) {
  lifetimes_trend_posneigh_25[row,"n_div"] = lifetimes_posneigh %>% filter(first_occ > lifetimes_trend_posneigh_25[row,"min_frame"] & first_occ < lifetimes_trend_posneigh_25[row,"max_frame"]) %>% nrow()
}
for (row in 1:nrow(lifetimes_trend_posneigh_25)) {
  lifetimes_trend_posneigh_25[row,"mean_life"] = (lifetimes_posneigh %>% filter(first_occ > lifetimes_trend_posneigh_25[row,"min_frame"] & first_occ < lifetimes_trend_posneigh_25[row,"max_frame"]))$lifetime %>% mean()
}
for (row in 1:nrow(lifetimes_trend_posneigh_25)) {
  lifetimes_trend_posneigh_25[row,"sd_life"] = (lifetimes_posneigh %>% filter(first_occ > lifetimes_trend_posneigh_25[row,"min_frame"] & first_occ < lifetimes_trend_posneigh_25[row,"max_frame"]))$lifetime %>% sd()
}
lifetimes_trend_posneigh_25$dev_time <- ((lifetimes_trend_posneigh_25$min_frame + lifetimes_trend_posneigh_25$max_frame)/2) * 2.5/60
lifetimes_trend_posneigh_25 <- lifetimes_trend_posneigh_25 %>% select(min_frame,max_frame,dev_time,n_div,mean_life,sd_life)
lifetimes_trend_posneigh_25$mean_life <- lifetimes_trend_posneigh_25$mean_life*2.5/60
lifetimes_trend_posneigh_25$sd_life <- lifetimes_trend_posneigh_25$sd_life*2.5/60

#
lifetimes_topposneigh <- cellinfoDB %>% filter(cell_id %in% toppos_neigh_roi$cell_id) %>% filter(cell_id %in% anterior_divdiv$cell_id) %>% select(first_occ,last_occ) %>% mutate(lifetime = last_occ-first_occ)

lifetimes_trend_topposneigh_25 <- frames %>% select(frame) %>% filter(frame %% 25 == 0)
lifetimes_trend_topposneigh_25 <- lifetimes_trend_topposneigh_25 %>% rename(min_frame = frame)
lifetimes_trend_topposneigh_25$max_frame <- lifetimes_trend_topposneigh_25$min_frame + 25 
for (row in 1:nrow(lifetimes_trend_topposneigh_25)) {
  lifetimes_trend_topposneigh_25[row,"n_div"] = lifetimes_topposneigh %>% filter(first_occ > lifetimes_trend_topposneigh_25[row,"min_frame"] & first_occ < lifetimes_trend_topposneigh_25[row,"max_frame"]) %>% nrow()
}
for (row in 1:nrow(lifetimes_trend_topposneigh_25)) {
  lifetimes_trend_topposneigh_25[row,"mean_life"] = (lifetimes_topposneigh %>% filter(first_occ > lifetimes_trend_topposneigh_25[row,"min_frame"] & first_occ < lifetimes_trend_topposneigh_25[row,"max_frame"]))$lifetime %>% mean()
}
for (row in 1:nrow(lifetimes_trend_topposneigh_25)) {
  lifetimes_trend_topposneigh_25[row,"sd_life"] = (lifetimes_topposneigh %>% filter(first_occ > lifetimes_trend_topposneigh_25[row,"min_frame"] & first_occ < lifetimes_trend_topposneigh_25[row,"max_frame"]))$lifetime %>% sd()
}
lifetimes_trend_topposneigh_25$dev_time <- ((lifetimes_trend_topposneigh_25$min_frame + lifetimes_trend_topposneigh_25$max_frame)/2) * 2.5/60
lifetimes_trend_topposneigh_25 <- lifetimes_trend_topposneigh_25 %>% select(min_frame,max_frame,dev_time,n_div,mean_life,sd_life)
lifetimes_trend_topposneigh_25$mean_life <- lifetimes_trend_topposneigh_25$mean_life*2.5/60
lifetimes_trend_topposneigh_25$sd_life <- lifetimes_trend_topposneigh_25$sd_life*2.5/60

#finally the anterior not pos neighs
lifetimes_antnotposneigh <- cellinfoDB %>% filter(cell_id %in% anterior_not_posneighs$cell_id) %>% filter(cell_id %in% anterior_divdiv$cell_id) %>% select(first_occ,last_occ) %>% mutate(lifetime = last_occ-first_occ)

lifetimes_trend_antnotposneigh_25 <- frames %>% select(frame) %>% filter(frame %% 25 == 0)
lifetimes_trend_antnotposneigh_25 <- lifetimes_trend_antnotposneigh_25 %>% rename(min_frame = frame)
lifetimes_trend_antnotposneigh_25$max_frame <- lifetimes_trend_antnotposneigh_25$min_frame + 25 
for (row in 1:nrow(lifetimes_trend_antnotposneigh_25)) {
  lifetimes_trend_antnotposneigh_25[row,"n_div"] = lifetimes_antnotposneigh %>% filter(first_occ > lifetimes_trend_antnotposneigh_25[row,"min_frame"] & first_occ < lifetimes_trend_antnotposneigh_25[row,"max_frame"]) %>% nrow()
}
for (row in 1:nrow(lifetimes_trend_antnotposneigh_25)) {
  lifetimes_trend_antnotposneigh_25[row,"mean_life"] = (lifetimes_antnotposneigh %>% filter(first_occ > lifetimes_trend_antnotposneigh_25[row,"min_frame"] & first_occ < lifetimes_trend_antnotposneigh_25[row,"max_frame"]))$lifetime %>% mean()
}
for (row in 1:nrow(lifetimes_trend_antnotposneigh_25)) {
  lifetimes_trend_antnotposneigh_25[row,"sd_life"] = (lifetimes_antnotposneigh %>% filter(first_occ > lifetimes_trend_antnotposneigh_25[row,"min_frame"] & first_occ < lifetimes_trend_antnotposneigh_25[row,"max_frame"]))$lifetime %>% sd()
}
lifetimes_trend_antnotposneigh_25$dev_time <- ((lifetimes_trend_antnotposneigh_25$min_frame + lifetimes_trend_antnotposneigh_25$max_frame)/2) * 2.5/60
lifetimes_trend_antnotposneigh_25 <- lifetimes_trend_antnotposneigh_25 %>% select(min_frame,max_frame,dev_time,n_div,mean_life,sd_life)
lifetimes_trend_antnotposneigh_25$mean_life <- lifetimes_trend_antnotposneigh_25$mean_life*2.5/60
lifetimes_trend_antnotposneigh_25$sd_life <- lifetimes_trend_antnotposneigh_25$sd_life*2.5/60


### plot all three regions.
myplot <- ggplot() +
  theme(legend.direction="vertical",legend.position="none", 
        legend.title = element_blank(), aspect.ratio=2/3, 
        text = element_text(size = 10), panel.grid.major.x = element_blank(), 
        panel.grid.minor.x = element_blank(),
        panel.grid.minor.y = element_blank(), panel.border = element_blank(), 
        axis.line = element_line(colour = "black",size=0.6), 
        panel.grid.major.y = element_line(colour = "grey", linetype = "solid", size=0.4), 
        axis.text=element_text(size=10, colour = "black"), 
        legend.text=element_text(size=10, colour = "black"), 
        axis.ticks=element_line(size=0.6,colour="black")) +
  #
  geom_errorbar(data=lifetimes_trend_antnotposneigh_25,aes(dev_time,ymin=(mean_life-sd_life), ymax=(mean_life+sd_life)),size=0.8, width=20/40,color="green") +
  geom_point(data=lifetimes_trend_antnotposneigh_25,aes(dev_time,mean_life),size=0.8,color="green") +
  geom_line(data=lifetimes_trend_antnotposneigh_25,aes(dev_time,mean_life),size=0.6,color="green") +
  #
  geom_errorbar(data=lifetimes_trend_topposneigh_25,aes(dev_time,ymin=(mean_life-sd_life), ymax=(mean_life+sd_life)),size=0.8, width=20/40,color="blue") +
  geom_point(data=lifetimes_trend_topposneigh_25,aes(dev_time,mean_life),size=0.8,color="blue") +
  geom_line(data=lifetimes_trend_topposneigh_25,aes(dev_time,mean_life),size=0.6,color="blue") +
  #
  geom_errorbar(data=lifetimes_trend_posneigh_25,aes(dev_time,ymin=(mean_life-sd_life), ymax=(mean_life+sd_life)),size=0.8, width=20/40,color="red") +
  geom_point(data=lifetimes_trend_posneigh_25,aes(dev_time,mean_life),size=0.8,color="red") +
  geom_line(data=lifetimes_trend_posneigh_25,aes(dev_time,mean_life),size=0.6,color="red") +  
  #
  scale_color_manual(values=movieColors) +
  scale_fill_manual(values=movieColors) +
  #scale_x_continuous(limits=c(16,36), breaks=seq(16,36,2.5), expand = c(0,0), labels = every_nth(seq(16,36,2.5), 2, inverse = TRUE)) +
  #ylim(0,0.4) +
  xlab("Time unadjusted")+
  ylab(expression(paste("Cell cycle time (hr)"))) 
#scale_x_continuous(limits=c(-2,18), breaks=c(0,4,8,12,16))
myplot <- set_panel_size(myplot,width  = unit(39, "mm"),
                         height = unit(39*2/3, "mm"))
ggsave("lifetime_spatial/lifetimes_trend_posneigh_topposneigh.pdf", plot = myplot, device="pdf",
       scale=1, width = 103*0.58, height=103*0.55, units = "mm",
       dpi = 1000, limitsize = TRUE,  useDingbats=FALSE)





